/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 3.0.7
 *
 * This file is not intended to be easily readable and contains a number of
 * coding conventions designed to improve portability and efficiency. Do not make
 * changes to this file unless you know what you are doing--modify the SWIG
 * interface file instead.
 * ----------------------------------------------------------------------------- */

#define SWIGPHP

#define SWIG_PREFIX ""
#define SWIG_PREFIX_LEN 0

#ifdef __cplusplus
/* SwigValueWrapper is described in swig.swg */
template<typename T> class SwigValueWrapper {
  struct SwigMovePointer {
    T *ptr;
    SwigMovePointer(T *p) : ptr(p) { }
    ~SwigMovePointer() { delete ptr; }
    SwigMovePointer& operator=(SwigMovePointer& rhs) { T* oldptr = ptr; ptr = 0; delete oldptr; ptr = rhs.ptr; rhs.ptr = 0; return *this; }
  } pointer;
  SwigValueWrapper& operator=(const SwigValueWrapper<T>& rhs);
  SwigValueWrapper(const SwigValueWrapper<T>& rhs);
public:
  SwigValueWrapper() : pointer(0) { }
  SwigValueWrapper& operator=(const T& t) { SwigMovePointer tmp(new T(t)); pointer = tmp; return *this; }
  operator T&() const { return *pointer.ptr; }
  T *operator&() { return pointer.ptr; }
};

template <typename T> T SwigValueInit() {
  return T();
}
#endif

/* -----------------------------------------------------------------------------
 *  This section contains generic SWIG labels for method/variable
 *  declarations/attributes, and other compiler dependent labels.
 * ----------------------------------------------------------------------------- */

/* template workaround for compilers that cannot correctly implement the C++ standard */
#ifndef SWIGTEMPLATEDISAMBIGUATOR
# if defined(__SUNPRO_CC) && (__SUNPRO_CC <= 0x560)
#  define SWIGTEMPLATEDISAMBIGUATOR template
# elif defined(__HP_aCC)
/* Needed even with `aCC -AA' when `aCC -V' reports HP ANSI C++ B3910B A.03.55 */
/* If we find a maximum version that requires this, the test would be __HP_aCC <= 35500 for A.03.55 */
#  define SWIGTEMPLATEDISAMBIGUATOR template
# else
#  define SWIGTEMPLATEDISAMBIGUATOR
# endif
#endif

/* inline attribute */
#ifndef SWIGINLINE
# if defined(__cplusplus) || (defined(__GNUC__) && !defined(__STRICT_ANSI__))
#   define SWIGINLINE inline
# else
#   define SWIGINLINE
# endif
#endif

/* attribute recognised by some compilers to avoid 'unused' warnings */
#ifndef SWIGUNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define SWIGUNUSED __attribute__ ((__unused__))
#   else
#     define SWIGUNUSED
#   endif
# elif defined(__ICC)
#   define SWIGUNUSED __attribute__ ((__unused__))
# else
#   define SWIGUNUSED
# endif
#endif

#ifndef SWIG_MSC_UNSUPPRESS_4505
# if defined(_MSC_VER)
#   pragma warning(disable : 4505) /* unreferenced local function has been removed */
# endif
#endif

#ifndef SWIGUNUSEDPARM
# ifdef __cplusplus
#   define SWIGUNUSEDPARM(p)
# else
#   define SWIGUNUSEDPARM(p) p SWIGUNUSED
# endif
#endif

/* internal SWIG method */
#ifndef SWIGINTERN
# define SWIGINTERN static SWIGUNUSED
#endif

/* internal inline SWIG method */
#ifndef SWIGINTERNINLINE
# define SWIGINTERNINLINE SWIGINTERN SWIGINLINE
#endif

/* exporting methods */
#if (__GNUC__ >= 4) || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4)
#  ifndef GCC_HASCLASSVISIBILITY
#    define GCC_HASCLASSVISIBILITY
#  endif
#endif

#ifndef SWIGEXPORT
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   if defined(STATIC_LINKED)
#     define SWIGEXPORT
#   else
#     define SWIGEXPORT __declspec(dllexport)
#   endif
# else
#   if defined(__GNUC__) && defined(GCC_HASCLASSVISIBILITY)
#     define SWIGEXPORT __attribute__ ((visibility("default")))
#   else
#     define SWIGEXPORT
#   endif
# endif
#endif

/* calling conventions for Windows */
#ifndef SWIGSTDCALL
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   define SWIGSTDCALL __stdcall
# else
#   define SWIGSTDCALL
# endif
#endif

/* Deal with Microsoft's attempt at deprecating C standard runtime functions */
#if !defined(SWIG_NO_CRT_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_CRT_SECURE_NO_DEPRECATE)
# define _CRT_SECURE_NO_DEPRECATE
#endif

/* Deal with Microsoft's attempt at deprecating methods in the standard C++ library */
#if !defined(SWIG_NO_SCL_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_SCL_SECURE_NO_DEPRECATE)
# define _SCL_SECURE_NO_DEPRECATE
#endif

/* Deal with Apple's deprecated 'AssertMacros.h' from Carbon-framework */
#if defined(__APPLE__) && !defined(__ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES)
# define __ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES 0
#endif

/* Intel's compiler complains if a variable which was never initialised is
 * cast to void, which is a common idiom which we use to indicate that we
 * are aware a variable isn't used.  So we just silence that warning.
 * See: https://github.com/swig/swig/issues/192 for more discussion.
 */
#ifdef __INTEL_COMPILER
# pragma warning disable 592
#endif

/* -----------------------------------------------------------------------------
 * swigrun.swg
 *
 * This file contains generic C API SWIG runtime support for pointer
 * type checking.
 * ----------------------------------------------------------------------------- */

/* This should only be incremented when either the layout of swig_type_info changes,
   or for whatever reason, the runtime changes incompatibly */
#define SWIG_RUNTIME_VERSION "4"

/* define SWIG_TYPE_TABLE_NAME as "SWIG_TYPE_TABLE" */
#ifdef SWIG_TYPE_TABLE
# define SWIG_QUOTE_STRING(x) #x
# define SWIG_EXPAND_AND_QUOTE_STRING(x) SWIG_QUOTE_STRING(x)
# define SWIG_TYPE_TABLE_NAME SWIG_EXPAND_AND_QUOTE_STRING(SWIG_TYPE_TABLE)
#else
# define SWIG_TYPE_TABLE_NAME
#endif

/*
  You can use the SWIGRUNTIME and SWIGRUNTIMEINLINE macros for
  creating a static or dynamic library from the SWIG runtime code.
  In 99.9% of the cases, SWIG just needs to declare them as 'static'.

  But only do this if strictly necessary, ie, if you have problems
  with your compiler or suchlike.
*/

#ifndef SWIGRUNTIME
# define SWIGRUNTIME SWIGINTERN
#endif

#ifndef SWIGRUNTIMEINLINE
# define SWIGRUNTIMEINLINE SWIGRUNTIME SWIGINLINE
#endif

/*  Generic buffer size */
#ifndef SWIG_BUFFER_SIZE
# define SWIG_BUFFER_SIZE 1024
#endif

/* Flags for pointer conversions */
#define SWIG_POINTER_DISOWN        0x1
#define SWIG_CAST_NEW_MEMORY       0x2

/* Flags for new pointer objects */
#define SWIG_POINTER_OWN           0x1


/*
   Flags/methods for returning states.

   The SWIG conversion methods, as ConvertPtr, return an integer
   that tells if the conversion was successful or not. And if not,
   an error code can be returned (see swigerrors.swg for the codes).

   Use the following macros/flags to set or process the returning
   states.

   In old versions of SWIG, code such as the following was usually written:

     if (SWIG_ConvertPtr(obj,vptr,ty.flags) != -1) {
       // success code
     } else {
       //fail code
     }

   Now you can be more explicit:

    int res = SWIG_ConvertPtr(obj,vptr,ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
    } else {
      // fail code
    }

   which is the same really, but now you can also do

    Type *ptr;
    int res = SWIG_ConvertPtr(obj,(void **)(&ptr),ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
      if (SWIG_IsNewObj(res) {
        ...
	delete *ptr;
      } else {
        ...
      }
    } else {
      // fail code
    }

   I.e., now SWIG_ConvertPtr can return new objects and you can
   identify the case and take care of the deallocation. Of course that
   also requires SWIG_ConvertPtr to return new result values, such as

      int SWIG_ConvertPtr(obj, ptr,...) {
        if (<obj is ok>) {
          if (<need new object>) {
            *ptr = <ptr to new allocated object>;
            return SWIG_NEWOBJ;
          } else {
            *ptr = <ptr to old object>;
            return SWIG_OLDOBJ;
          }
        } else {
          return SWIG_BADOBJ;
        }
      }

   Of course, returning the plain '0(success)/-1(fail)' still works, but you can be
   more explicit by returning SWIG_BADOBJ, SWIG_ERROR or any of the
   SWIG errors code.

   Finally, if the SWIG_CASTRANK_MODE is enabled, the result code
   allows to return the 'cast rank', for example, if you have this

       int food(double)
       int fooi(int);

   and you call

      food(1)   // cast rank '1'  (1 -> 1.0)
      fooi(1)   // cast rank '0'

   just use the SWIG_AddCast()/SWIG_CheckState()
*/

#define SWIG_OK                    (0)
#define SWIG_ERROR                 (-1)
#define SWIG_IsOK(r)               (r >= 0)
#define SWIG_ArgError(r)           ((r != SWIG_ERROR) ? r : SWIG_TypeError)

/* The CastRankLimit says how many bits are used for the cast rank */
#define SWIG_CASTRANKLIMIT         (1 << 8)
/* The NewMask denotes the object was created (using new/malloc) */
#define SWIG_NEWOBJMASK            (SWIG_CASTRANKLIMIT  << 1)
/* The TmpMask is for in/out typemaps that use temporal objects */
#define SWIG_TMPOBJMASK            (SWIG_NEWOBJMASK << 1)
/* Simple returning values */
#define SWIG_BADOBJ                (SWIG_ERROR)
#define SWIG_OLDOBJ                (SWIG_OK)
#define SWIG_NEWOBJ                (SWIG_OK | SWIG_NEWOBJMASK)
#define SWIG_TMPOBJ                (SWIG_OK | SWIG_TMPOBJMASK)
/* Check, add and del mask methods */
#define SWIG_AddNewMask(r)         (SWIG_IsOK(r) ? (r | SWIG_NEWOBJMASK) : r)
#define SWIG_DelNewMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_NEWOBJMASK) : r)
#define SWIG_IsNewObj(r)           (SWIG_IsOK(r) && (r & SWIG_NEWOBJMASK))
#define SWIG_AddTmpMask(r)         (SWIG_IsOK(r) ? (r | SWIG_TMPOBJMASK) : r)
#define SWIG_DelTmpMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_TMPOBJMASK) : r)
#define SWIG_IsTmpObj(r)           (SWIG_IsOK(r) && (r & SWIG_TMPOBJMASK))

/* Cast-Rank Mode */
#if defined(SWIG_CASTRANK_MODE)
#  ifndef SWIG_TypeRank
#    define SWIG_TypeRank             unsigned long
#  endif
#  ifndef SWIG_MAXCASTRANK            /* Default cast allowed */
#    define SWIG_MAXCASTRANK          (2)
#  endif
#  define SWIG_CASTRANKMASK          ((SWIG_CASTRANKLIMIT) -1)
#  define SWIG_CastRank(r)           (r & SWIG_CASTRANKMASK)
SWIGINTERNINLINE int SWIG_AddCast(int r) {
  return SWIG_IsOK(r) ? ((SWIG_CastRank(r) < SWIG_MAXCASTRANK) ? (r + 1) : SWIG_ERROR) : r;
}
SWIGINTERNINLINE int SWIG_CheckState(int r) {
  return SWIG_IsOK(r) ? SWIG_CastRank(r) + 1 : 0;
}
#else /* no cast-rank mode */
#  define SWIG_AddCast(r) (r)
#  define SWIG_CheckState(r) (SWIG_IsOK(r) ? 1 : 0)
#endif


#include <string.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef void *(*swig_converter_func)(void *, int *);
typedef struct swig_type_info *(*swig_dycast_func)(void **);

/* Structure to store information on one type */
typedef struct swig_type_info {
  const char             *name;			/* mangled name of this type */
  const char             *str;			/* human readable name of this type */
  swig_dycast_func        dcast;		/* dynamic cast function down a hierarchy */
  struct swig_cast_info  *cast;			/* linked list of types that can cast into this type */
  void                   *clientdata;		/* language specific type data */
  int                    owndata;		/* flag if the structure owns the clientdata */
} swig_type_info;

/* Structure to store a type and conversion function used for casting */
typedef struct swig_cast_info {
  swig_type_info         *type;			/* pointer to type that is equivalent to this type */
  swig_converter_func     converter;		/* function to cast the void pointers */
  struct swig_cast_info  *next;			/* pointer to next cast in linked list */
  struct swig_cast_info  *prev;			/* pointer to the previous cast */
} swig_cast_info;

/* Structure used to store module information
 * Each module generates one structure like this, and the runtime collects
 * all of these structures and stores them in a circularly linked list.*/
typedef struct swig_module_info {
  swig_type_info         **types;		/* Array of pointers to swig_type_info structures that are in this module */
  size_t                 size;		        /* Number of types in this module */
  struct swig_module_info *next;		/* Pointer to next element in circularly linked list */
  swig_type_info         **type_initial;	/* Array of initially generated type structures */
  swig_cast_info         **cast_initial;	/* Array of initially generated casting structures */
  void                    *clientdata;		/* Language specific module data */
} swig_module_info;

/*
  Compare two type names skipping the space characters, therefore
  "char*" == "char *" and "Class<int>" == "Class<int >", etc.

  Return 0 when the two name types are equivalent, as in
  strncmp, but skipping ' '.
*/
SWIGRUNTIME int
SWIG_TypeNameComp(const char *f1, const char *l1,
		  const char *f2, const char *l2) {
  for (;(f1 != l1) && (f2 != l2); ++f1, ++f2) {
    while ((*f1 == ' ') && (f1 != l1)) ++f1;
    while ((*f2 == ' ') && (f2 != l2)) ++f2;
    if (*f1 != *f2) return (*f1 > *f2) ? 1 : -1;
  }
  return (int)((l1 - f1) - (l2 - f2));
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if equal, -1 if nb < tb, 1 if nb > tb
*/
SWIGRUNTIME int
SWIG_TypeCmp(const char *nb, const char *tb) {
  int equiv = 1;
  const char* te = tb + strlen(tb);
  const char* ne = nb;
  while (equiv != 0 && *ne) {
    for (nb = ne; *ne; ++ne) {
      if (*ne == '|') break;
    }
    equiv = SWIG_TypeNameComp(nb, ne, tb, te);
    if (*ne) ++ne;
  }
  return equiv;
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if not equal, 1 if equal
*/
SWIGRUNTIME int
SWIG_TypeEquiv(const char *nb, const char *tb) {
  return SWIG_TypeCmp(nb, tb) == 0 ? 1 : 0;
}

/*
  Check the typename
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheck(const char *c, swig_type_info *ty) {
  if (ty) {
    swig_cast_info *iter = ty->cast;
    while (iter) {
      if (strcmp(iter->type->name, c) == 0) {
        if (iter == ty->cast)
          return iter;
        /* Move iter to the top of the linked list */
        iter->prev->next = iter->next;
        if (iter->next)
          iter->next->prev = iter->prev;
        iter->next = ty->cast;
        iter->prev = 0;
        if (ty->cast) ty->cast->prev = iter;
        ty->cast = iter;
        return iter;
      }
      iter = iter->next;
    }
  }
  return 0;
}

/*
  Identical to SWIG_TypeCheck, except strcmp is replaced with a pointer comparison
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheckStruct(swig_type_info *from, swig_type_info *ty) {
  if (ty) {
    swig_cast_info *iter = ty->cast;
    while (iter) {
      if (iter->type == from) {
        if (iter == ty->cast)
          return iter;
        /* Move iter to the top of the linked list */
        iter->prev->next = iter->next;
        if (iter->next)
          iter->next->prev = iter->prev;
        iter->next = ty->cast;
        iter->prev = 0;
        if (ty->cast) ty->cast->prev = iter;
        ty->cast = iter;
        return iter;
      }
      iter = iter->next;
    }
  }
  return 0;
}

/*
  Cast a pointer up an inheritance hierarchy
*/
SWIGRUNTIMEINLINE void *
SWIG_TypeCast(swig_cast_info *ty, void *ptr, int *newmemory) {
  return ((!ty) || (!ty->converter)) ? ptr : (*ty->converter)(ptr, newmemory);
}

/*
   Dynamic pointer casting. Down an inheritance hierarchy
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeDynamicCast(swig_type_info *ty, void **ptr) {
  swig_type_info *lastty = ty;
  if (!ty || !ty->dcast) return ty;
  while (ty && (ty->dcast)) {
    ty = (*ty->dcast)(ptr);
    if (ty) lastty = ty;
  }
  return lastty;
}

/*
  Return the name associated with this type
*/
SWIGRUNTIMEINLINE const char *
SWIG_TypeName(const swig_type_info *ty) {
  return ty->name;
}

/*
  Return the pretty name associated with this type,
  that is an unmangled type name in a form presentable to the user.
*/
SWIGRUNTIME const char *
SWIG_TypePrettyName(const swig_type_info *type) {
  /* The "str" field contains the equivalent pretty names of the
     type, separated by vertical-bar characters.  We choose
     to print the last name, as it is often (?) the most
     specific. */
  if (!type) return NULL;
  if (type->str != NULL) {
    const char *last_name = type->str;
    const char *s;
    for (s = type->str; *s; s++)
      if (*s == '|') last_name = s+1;
    return last_name;
  }
  else
    return type->name;
}

/*
   Set the clientdata field for a type
*/
SWIGRUNTIME void
SWIG_TypeClientData(swig_type_info *ti, void *clientdata) {
  swig_cast_info *cast = ti->cast;
  /* if (ti->clientdata == clientdata) return; */
  ti->clientdata = clientdata;

  while (cast) {
    if (!cast->converter) {
      swig_type_info *tc = cast->type;
      if (!tc->clientdata) {
	SWIG_TypeClientData(tc, clientdata);
      }
    }
    cast = cast->next;
  }
}
SWIGRUNTIME void
SWIG_TypeNewClientData(swig_type_info *ti, void *clientdata) {
  SWIG_TypeClientData(ti, clientdata);
  ti->owndata = 1;
}

/*
  Search for a swig_type_info structure only by mangled name
  Search is a O(log #types)

  We start searching at module start, and finish searching when start == end.
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_MangledTypeQueryModule(swig_module_info *start,
                            swig_module_info *end,
		            const char *name) {
  swig_module_info *iter = start;
  do {
    if (iter->size) {
      size_t l = 0;
      size_t r = iter->size - 1;
      do {
	/* since l+r >= 0, we can (>> 1) instead (/ 2) */
	size_t i = (l + r) >> 1;
	const char *iname = iter->types[i]->name;
	if (iname) {
	  int compare = strcmp(name, iname);
	  if (compare == 0) {
	    return iter->types[i];
	  } else if (compare < 0) {
	    if (i) {
	      r = i - 1;
	    } else {
	      break;
	    }
	  } else if (compare > 0) {
	    l = i + 1;
	  }
	} else {
	  break; /* should never happen */
	}
      } while (l <= r);
    }
    iter = iter->next;
  } while (iter != end);
  return 0;
}

/*
  Search for a swig_type_info structure for either a mangled name or a human readable name.
  It first searches the mangled names of the types, which is a O(log #types)
  If a type is not found it then searches the human readable names, which is O(#types).

  We start searching at module start, and finish searching when start == end.
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeQueryModule(swig_module_info *start,
                     swig_module_info *end,
		     const char *name) {
  /* STEP 1: Search the name field using binary search */
  swig_type_info *ret = SWIG_MangledTypeQueryModule(start, end, name);
  if (ret) {
    return ret;
  } else {
    /* STEP 2: If the type hasn't been found, do a complete search
       of the str field (the human readable name) */
    swig_module_info *iter = start;
    do {
      size_t i = 0;
      for (; i < iter->size; ++i) {
	if (iter->types[i]->str && (SWIG_TypeEquiv(iter->types[i]->str, name)))
	  return iter->types[i];
      }
      iter = iter->next;
    } while (iter != end);
  }

  /* neither found a match */
  return 0;
}

/*
   Pack binary data into a string
*/
SWIGRUNTIME char *
SWIG_PackData(char *c, void *ptr, size_t sz) {
  static const char hex[17] = "0123456789abcdef";
  const unsigned char *u = (unsigned char *) ptr;
  const unsigned char *eu =  u + sz;
  for (; u != eu; ++u) {
    unsigned char uu = *u;
    *(c++) = hex[(uu & 0xf0) >> 4];
    *(c++) = hex[uu & 0xf];
  }
  return c;
}

/*
   Unpack binary data from a string
*/
SWIGRUNTIME const char *
SWIG_UnpackData(const char *c, void *ptr, size_t sz) {
  unsigned char *u = (unsigned char *) ptr;
  const unsigned char *eu = u + sz;
  for (; u != eu; ++u) {
    char d = *(c++);
    unsigned char uu;
    if ((d >= '0') && (d <= '9'))
      uu = ((d - '0') << 4);
    else if ((d >= 'a') && (d <= 'f'))
      uu = ((d - ('a'-10)) << 4);
    else
      return (char *) 0;
    d = *(c++);
    if ((d >= '0') && (d <= '9'))
      uu |= (d - '0');
    else if ((d >= 'a') && (d <= 'f'))
      uu |= (d - ('a'-10));
    else
      return (char *) 0;
    *u = uu;
  }
  return c;
}

/*
   Pack 'void *' into a string buffer.
*/
SWIGRUNTIME char *
SWIG_PackVoidPtr(char *buff, void *ptr, const char *name, size_t bsz) {
  char *r = buff;
  if ((2*sizeof(void *) + 2) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,&ptr,sizeof(void *));
  if (strlen(name) + 1 > (bsz - (r - buff))) return 0;
  strcpy(r,name);
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackVoidPtr(const char *c, void **ptr, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      *ptr = (void *) 0;
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sizeof(void *));
}

SWIGRUNTIME char *
SWIG_PackDataName(char *buff, void *ptr, size_t sz, const char *name, size_t bsz) {
  char *r = buff;
  size_t lname = (name ? strlen(name) : 0);
  if ((2*sz + 2 + lname) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,ptr,sz);
  if (lname) {
    strncpy(r,name,lname+1);
  } else {
    *r = 0;
  }
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackDataName(const char *c, void *ptr, size_t sz, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      memset(ptr,0,sz);
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sz);
}

#ifdef __cplusplus
}
#endif

/* -----------------------------------------------------------------------------
 * phprun.swg
 *
 * PHP runtime library
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#endif
#include "zend.h"
#include "zend_API.h"
#include "zend_exceptions.h"
#include "php.h"
#include "ext/standard/php_string.h"
#include <stdlib.h> /* for abort(), used in generated code. */

#ifdef ZEND_RAW_FENTRY
/* ZEND_RAW_FENTRY was added somewhere between 5.2.0 and 5.2.3 */
# define SWIG_ZEND_NAMED_FE(ZN, N, A) ZEND_RAW_FENTRY((char*)#ZN, N, A, 0)
#else
/* This causes warnings from GCC >= 4.2 (assigning a string literal to char*).
 * But this seems to be unavoidable without directly assuming knowledge of
 * the structure, which changed between PHP4 and PHP5. */
# define SWIG_ZEND_NAMED_FE(ZN, N, A) ZEND_NAMED_FE(ZN, N, A)
#endif

#ifndef Z_SET_ISREF_P
/* For PHP < 5.3 */
# define Z_SET_ISREF_P(z) (z)->is_ref = 1
#endif
#ifndef Z_SET_REFCOUNT_P
/* For PHP < 5.3 */
# define Z_SET_REFCOUNT_P(z, rc) (z)->refcount = (rc)
#endif

#define SWIG_LONG_CONSTANT(N, V) zend_register_long_constant((char*)#N, sizeof(#N), V, CONST_CS | CONST_PERSISTENT, module_number TSRMLS_CC)
#define SWIG_DOUBLE_CONSTANT(N, V) zend_register_double_constant((char*)#N, sizeof(#N), V, CONST_CS | CONST_PERSISTENT, module_number TSRMLS_CC)
#define SWIG_STRING_CONSTANT(N, V) zend_register_stringl_constant((char*)#N, sizeof(#N), (char*)(V), strlen(V), CONST_CS | CONST_PERSISTENT, module_number TSRMLS_CC)
#define SWIG_CHAR_CONSTANT(N, V) do {\
    static char swig_char = (V);\
    zend_register_stringl_constant((char*)#N, sizeof(#N), &swig_char, 1, CONST_CS | CONST_PERSISTENT, module_number TSRMLS_CC);\
} while (0)

/* These TSRMLS_ stuff should already be defined now, but with older php under
   redhat are not... */
#ifndef TSRMLS_D
#define TSRMLS_D
#endif
#ifndef TSRMLS_DC
#define TSRMLS_DC
#endif
#ifndef TSRMLS_C
#define TSRMLS_C
#endif
#ifndef TSRMLS_CC
#define TSRMLS_CC
#endif

#ifdef __cplusplus
}
#endif

/* But in fact SWIG_ConvertPtr is the native interface for getting typed
   pointer values out of zvals.  We need the TSRMLS_ macros for when we
   make PHP type calls later as we handle php resources */
#define SWIG_ConvertPtr(obj,pp,type,flags) SWIG_ZTS_ConvertPtr(obj,pp,type,flags TSRMLS_CC)


#define SWIG_fail goto fail

static const char *default_error_msg = "Unknown error occurred";
static int default_error_code = E_ERROR;

#define SWIG_PHP_Arg_Error_Msg(argnum,extramsg) "Error in argument " #argnum " "#extramsg

#define SWIG_PHP_Error(code,msg) do { SWIG_ErrorCode() = code; SWIG_ErrorMsg() = msg; SWIG_fail; } while (0)

#define SWIG_contract_assert(expr,msg) \
  if (!(expr) ) { zend_printf("Contract Assert Failed %s\n",msg ); } else

/* Standard SWIG API */
#define SWIG_GetModule(clientdata) SWIG_Php_GetModule()
#define SWIG_SetModule(clientdata, pointer) SWIG_Php_SetModule(pointer)

/* used to wrap returned objects in so we know whether they are newobject
   and need freeing, or not */
typedef struct {
  void * ptr;
  int newobject;
} swig_object_wrapper;

/* empty zend destructor for types without one */
static ZEND_RSRC_DTOR_FUNC(SWIG_landfill) { (void)rsrc; }

#define SWIG_SetPointerZval(a,b,c,d) SWIG_ZTS_SetPointerZval(a,b,c,d TSRMLS_CC)
#define SWIG_as_voidptr(a) const_cast< void * >(static_cast< const void * >(a))

static void
SWIG_ZTS_SetPointerZval(zval *z, void *ptr, swig_type_info *type, int newobject TSRMLS_DC) {
  /*
   * First test for Null pointers.  Return those as PHP native NULL
   */
  if (!ptr ) {
    ZVAL_NULL(z);
    return;
  }
  if (type->clientdata) {
    swig_object_wrapper *value;
    if (! (*(int *)(type->clientdata)))
      zend_error(E_ERROR, "Type: %s failed to register with zend",type->name);
    value=(swig_object_wrapper *)emalloc(sizeof(swig_object_wrapper));
    value->ptr=ptr;
    value->newobject=(newobject & 1);
    if ((newobject & 2) == 0) {
      /* Just register the pointer as a resource. */
      ZEND_REGISTER_RESOURCE(z, value, *(int *)(type->clientdata));
    } else {
      /*
       * Wrap the resource in an object, the resource will be accessible
       * via the "_cPtr" member. This is currently only used by
       * directorin typemaps.
       */
      zval *resource;
      zend_class_entry **ce = NULL;
      const char *type_name = type->name+3; /* +3 so: _p_Foo -> Foo */
      size_t type_name_len;
      int result;
      const char * p;

      /* Namespace__Foo -> Foo */
      /* FIXME: ugly and goes wrong for classes with __ in their names. */
      while ((p = strstr(type_name, "__")) != NULL) {
        type_name = p + 2;
      }
      type_name_len = strlen(type_name);

      MAKE_STD_ZVAL(resource);
      ZEND_REGISTER_RESOURCE(resource, value, *(int *)(type->clientdata));
      if (SWIG_PREFIX_LEN > 0) {
        char * classname = (char*)emalloc(SWIG_PREFIX_LEN + type_name_len + 1);
        strcpy(classname, SWIG_PREFIX);
        strcpy(classname + SWIG_PREFIX_LEN, type_name);
        result = zend_lookup_class(classname, SWIG_PREFIX_LEN + type_name_len, &ce TSRMLS_CC);
        efree(classname);
      } else {
        result = zend_lookup_class((char *)type_name, type_name_len, &ce TSRMLS_CC);
      }
      if (result != SUCCESS) {
        /* class does not exist */
        object_init(z);
      } else {
        object_init_ex(z, *ce);
      }
      Z_SET_REFCOUNT_P(z, 1);
      Z_SET_ISREF_P(z);
      zend_hash_update(HASH_OF(z), (char*)"_cPtr", sizeof("_cPtr"), (void*)&resource, sizeof(zval*), NULL);
    }
    return;
  }
  zend_error(E_ERROR, "Type: %s not registered with zend",type->name);
}

/* This pointer conversion routine takes the native pointer p (along with
   its type name) and converts it by calling appropriate casting functions
   according to ty.  The resultant pointer is returned, or NULL is returned
   if the pointer can't be cast.

   Sadly PHP has no API to find a type name from a type id, only from an
   instance of a resource of the type id, so we have to pass type_name as well.

   The two functions which might call this are:
   SWIG_ZTS_ConvertResourcePtr which gets the type name from the resource
   and the registered zend destructors for which we have one per type each
   with the type name hard wired in. */
static void *
SWIG_ZTS_ConvertResourceData(void * p, const char *type_name, swig_type_info *ty TSRMLS_DC) {
  swig_cast_info *tc;
  void *result = 0;

  if (!ty) {
    /* They don't care about the target type, so just pass on the pointer! */
    return p;
  }

  if (! type_name) {  
    /* can't convert p to ptr type ty if we don't know what type p is */
    return NULL;
  }

  /* convert and cast p from type_name to ptr as ty. */
  tc = SWIG_TypeCheck(type_name, ty);
  if (tc) {
    int newmemory = 0;
    result = SWIG_TypeCast(tc, p, &newmemory);
    assert(!newmemory); /* newmemory handling not yet implemented */
  }
  return result;
}

/* This function returns a pointer of type ty by extracting the pointer
   and type info from the resource in z.  z must be a resource.
   If it fails, NULL is returned.
   It uses SWIG_ZTS_ConvertResourceData to do the real work. */
static void *
SWIG_ZTS_ConvertResourcePtr(zval *z, swig_type_info *ty, int flags TSRMLS_DC) {
  swig_object_wrapper *value;
  void *p;
  int type;
  const char *type_name;

  value = (swig_object_wrapper *) zend_list_find(z->value.lval, &type);
  if (type==-1) return NULL;
  if (flags & SWIG_POINTER_DISOWN) {
    value->newobject = 0;
  }
  p = value->ptr;

  type_name=zend_rsrc_list_get_rsrc_type(z->value.lval TSRMLS_CC);

  return SWIG_ZTS_ConvertResourceData(p, type_name, ty TSRMLS_CC);
}

/* We allow passing of a RESOURCE pointing to the object or an OBJECT whose
   _cPtr is a resource pointing to the object */
static int
SWIG_ZTS_ConvertPtr(zval *z, void **ptr, swig_type_info *ty, int flags TSRMLS_DC) {
  if (z == NULL) {
    *ptr = 0;
    return 0;
  }

  switch (z->type) {
    case IS_OBJECT: {
      zval ** _cPtr;
      if (zend_hash_find(HASH_OF(z),(char*)"_cPtr",sizeof("_cPtr"),(void**)&_cPtr)==SUCCESS) {
	if ((*_cPtr)->type==IS_RESOURCE) {
	  *ptr = SWIG_ZTS_ConvertResourcePtr(*_cPtr, ty, flags TSRMLS_CC);
	  return (*ptr == NULL ? -1 : 0);
	}
      }
      break;
    }
    case IS_RESOURCE:
      *ptr = SWIG_ZTS_ConvertResourcePtr(z, ty, flags TSRMLS_CC);
      return (*ptr == NULL ? -1 : 0);
    case IS_NULL:
      *ptr = 0;
      return 0;
  }

  return -1;
}

static char const_name[] = "swig_runtime_data_type_pointer";
static swig_module_info *SWIG_Php_GetModule() {
  zval *pointer;
  swig_module_info *ret = 0;
  TSRMLS_FETCH();

  MAKE_STD_ZVAL(pointer);

  if (zend_get_constant(const_name, sizeof(const_name) - 1, pointer TSRMLS_CC)) {
    if (pointer->type == IS_LONG) {
      ret = (swig_module_info *) pointer->value.lval;
    }
  } 
  FREE_ZVAL(pointer);
  return ret; 
}

static void SWIG_Php_SetModule(swig_module_info *pointer) {
  TSRMLS_FETCH();
  REGISTER_MAIN_LONG_CONSTANT(const_name, (long) pointer, 0);
}

/*  Errors in SWIG */
#define  SWIG_UnknownError    	   -1
#define  SWIG_IOError        	   -2
#define  SWIG_RuntimeError   	   -3
#define  SWIG_IndexError     	   -4
#define  SWIG_TypeError      	   -5
#define  SWIG_DivisionByZero 	   -6
#define  SWIG_OverflowError  	   -7
#define  SWIG_SyntaxError    	   -8
#define  SWIG_ValueError     	   -9
#define  SWIG_SystemError    	   -10
#define  SWIG_AttributeError 	   -11
#define  SWIG_MemoryError    	   -12
#define  SWIG_NullReferenceError   -13




/* -------- TYPES TABLE (BEGIN) -------- */

#define SWIGTYPE_p_Match swig_types[0]
#define SWIGTYPE_p_Provider swig_types[1]
#define SWIGTYPE_p_difference_type swig_types[2]
#define SWIGTYPE_p_key_type swig_types[3]
#define SWIGTYPE_p_mapped_type swig_types[4]
#define SWIGTYPE_p_size_type swig_types[5]
#define SWIGTYPE_p_std__mapT_std__string_std__string_t swig_types[6]
#define SWIGTYPE_p_std__string swig_types[7]
#define SWIGTYPE_p_std__vectorT_std__string_t swig_types[8]
#define SWIGTYPE_p_value_type swig_types[9]
static swig_type_info *swig_types[11];
static swig_module_info swig_module = {swig_types, 10, 0, 0, 0, 0};
#define SWIG_TypeQuery(name) SWIG_TypeQueryModule(&swig_module, &swig_module, name)
#define SWIG_MangledTypeQuery(name) SWIG_MangledTypeQueryModule(&swig_module, &swig_module, name)

/* -------- TYPES TABLE (END) -------- */

/* header section */
ZEND_BEGIN_MODULE_GLOBALS(FiftyOneDegreesTrieV3)
const char *error_msg;
int error_code;
ZEND_END_MODULE_GLOBALS(FiftyOneDegreesTrieV3)
ZEND_DECLARE_MODULE_GLOBALS(FiftyOneDegreesTrieV3)
#ifdef ZTS
#define SWIG_ErrorMsg() TSRMG(FiftyOneDegreesTrieV3_globals_id, zend_FiftyOneDegreesTrieV3_globals *, error_msg )
#define SWIG_ErrorCode() TSRMG(FiftyOneDegreesTrieV3_globals_id, zend_FiftyOneDegreesTrieV3_globals *, error_code )
#else
#define SWIG_ErrorMsg() (FiftyOneDegreesTrieV3_globals.error_msg)
#define SWIG_ErrorCode() (FiftyOneDegreesTrieV3_globals.error_code)
#endif

#ifdef __GNUC__
static void SWIG_FAIL(TSRMLS_D) __attribute__ ((__noreturn__));
#endif

static void SWIG_FAIL(TSRMLS_D) {
    zend_error(SWIG_ErrorCode(), "%s", SWIG_ErrorMsg());
    abort();
}

static void FiftyOneDegreesTrieV3_init_globals(zend_FiftyOneDegreesTrieV3_globals *globals ) {
  globals->error_msg = default_error_msg;
  globals->error_code = default_error_code;
}
static void FiftyOneDegreesTrieV3_destroy_globals(zend_FiftyOneDegreesTrieV3_globals * globals) { (void)globals; }

static void SWIG_ResetError(TSRMLS_D) {
  SWIG_ErrorMsg() = default_error_msg;
  SWIG_ErrorCode() = default_error_code;
}

ZEND_NAMED_FUNCTION(_wrap_swig_FiftyOneDegreesTrieV3_alter_newobject) {
  zval **args[2];
  swig_object_wrapper *value;
  int type;

  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }

  value = (swig_object_wrapper *) zend_list_find((*args[0])->value.lval, &type);
  value->newobject = zval_is_true(*args[1]);

  return;
}
ZEND_NAMED_FUNCTION(_wrap_swig_FiftyOneDegreesTrieV3_get_newobject) {
  zval **args[1];
  swig_object_wrapper *value;
  int type;

  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }

  value = (swig_object_wrapper *) zend_list_find((*args[0])->value.lval, &type);
  RETVAL_LONG(value->newobject);

  return;
}
#define SWIG_name  "FiftyOneDegreesTrieV3"
#ifdef __cplusplus
extern "C" {
#endif
#include "php.h"
#include "php_ini.h"
#include "ext/standard/info.h"
#include "php_FiftyOneDegreesTrieV3.h"
#ifdef __cplusplus
}
#endif


	#include "Provider.hpp"
	#include "Match.hpp"

	#ifdef SWIGPHP
	Provider *provider;

	PHP_INI_BEGIN()
	PHP_INI_ENTRY("FiftyOneDegreesTrieV3.data_file", "/usr/lib/php5/51Degrees.trie", PHP_INI_ALL, NULL)
	PHP_INI_ENTRY("FiftyOneDegreesTrieV3.property_list", NULL, PHP_INI_ALL, NULL)
	PHP_INI_END()
	#endif



#include "zend_exceptions.h"
#define SWIG_exception(code, msg) zend_throw_exception(NULL, (char*)msg, code TSRMLS_CC)


#include <stdexcept>


#include <string>


#include <stdexcept>


#include <utility>


#include <vector>
#include <stdexcept>


#include <map>
#include <algorithm>
#include <stdexcept>

SWIGINTERN std::string const &std_map_Sl_std_string_Sc_std_string_Sg__get(std::map< std::string,std::string > *self,std::string const &key){
                std::map<std::string,std::string >::iterator i = self->find(key);
                if (i != self->end())
                    return i->second;
                else
                    throw std::out_of_range("key not found");
            }
SWIGINTERN void std_map_Sl_std_string_Sc_std_string_Sg__set(std::map< std::string,std::string > *self,std::string const &key,std::string const &x){
                (*self)[key] = x;
            }
SWIGINTERN void std_map_Sl_std_string_Sc_std_string_Sg__del(std::map< std::string,std::string > *self,std::string const &key){
                std::map<std::string,std::string >::iterator i = self->find(key);
                if (i != self->end())
                    self->erase(i);
                else
                    throw std::out_of_range("key not found");
            }
SWIGINTERN bool std_map_Sl_std_string_Sc_std_string_Sg__has_key(std::map< std::string,std::string > *self,std::string const &key){
                std::map<std::string,std::string >::iterator i = self->find(key);
                return i != self->end();
            }
SWIGINTERN bool std_map_Sl_std_string_Sc_std_string_Sg__is_empty(std::map< std::string,std::string > const *self){
                return self->empty();
            }
SWIGINTERN bool std_vector_Sl_std_string_Sg__is_empty(std::vector< std::string > const *self){
        return self->empty();
      }
SWIGINTERN std::string std_vector_Sl_std_string_Sg__pop(std::vector< std::string > *self){
        if (self->size() == 0)
          throw std::out_of_range("pop from empty vector");
        std::string x = self->back();
        self->pop_back();
        return x;
      }
SWIGINTERN std::vector< std::string >::const_reference std_vector_Sl_std_string_Sg__get(std::vector< std::string > *self,int i){
        int size = int(self->size());
        if (i>=0 && i<size)
          return (*self)[i];
        else
          throw std::out_of_range("vector index out of range");
      }
SWIGINTERN void std_vector_Sl_std_string_Sg__set(std::vector< std::string > *self,int i,std::vector< std::string >::value_type const &val){
        int size = int(self->size());
        if (i>=0 && i<size)
          (*self)[i] = val;
        else
          throw std::out_of_range("vector index out of range");
      }

/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (BEGIN) -------- */

static swig_type_info _swigt__p_Match = {"_p_Match", "Match *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_Provider = {"_p_Provider", "Provider *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_difference_type = {"_p_difference_type", "difference_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_key_type = {"_p_key_type", "key_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_mapped_type = {"_p_mapped_type", "mapped_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_size_type = {"_p_size_type", "size_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__mapT_std__string_std__string_t = {"_p_std__mapT_std__string_std__string_t", "std::map< std::string,std::string > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__string = {"_p_std__string", "std::string *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_std__string_t = {"_p_std__vectorT_std__string_t", "std::vector< std::string > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_value_type = {"_p_value_type", "value_type *", 0, 0, (void*)0, 0};

static swig_type_info *swig_type_initial[] = {
  &_swigt__p_Match,
  &_swigt__p_Provider,
  &_swigt__p_difference_type,
  &_swigt__p_key_type,
  &_swigt__p_mapped_type,
  &_swigt__p_size_type,
  &_swigt__p_std__mapT_std__string_std__string_t,
  &_swigt__p_std__string,
  &_swigt__p_std__vectorT_std__string_t,
  &_swigt__p_value_type,
};

static swig_cast_info _swigc__p_Match[] = {  {&_swigt__p_Match, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_Provider[] = {  {&_swigt__p_Provider, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_difference_type[] = {  {&_swigt__p_difference_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_key_type[] = {  {&_swigt__p_key_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_mapped_type[] = {  {&_swigt__p_mapped_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_size_type[] = {  {&_swigt__p_size_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__mapT_std__string_std__string_t[] = {  {&_swigt__p_std__mapT_std__string_std__string_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__string[] = {  {&_swigt__p_std__string, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_std__string_t[] = {  {&_swigt__p_std__vectorT_std__string_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_value_type[] = {  {&_swigt__p_value_type, 0, 0, 0},{0, 0, 0, 0}};

static swig_cast_info *swig_cast_initial[] = {
  _swigc__p_Match,
  _swigc__p_Provider,
  _swigc__p_difference_type,
  _swigc__p_key_type,
  _swigc__p_mapped_type,
  _swigc__p_size_type,
  _swigc__p_std__mapT_std__string_std__string_t,
  _swigc__p_std__string,
  _swigc__p_std__vectorT_std__string_t,
  _swigc__p_value_type,
};


/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (END) -------- */

/* end header section */
/* vdecl subsection */
static int le_swig__p_key_type=0; /* handle for _p_key_type */
static int le_swig__p_mapped_type=0; /* handle for _p_mapped_type */
static int le_swig__p_difference_type=0; /* handle for _p_difference_type */
static int le_swig__p_std__mapT_std__string_std__string_t=0; /* handle for MapStringString */
static int le_swig__p_value_type=0; /* handle for _p_value_type */
static int le_swig__p_std__vectorT_std__string_t=0; /* handle for VectorString */
static int le_swig__p_Match=0; /* handle for Match */
static int le_swig__p_size_type=0; /* handle for _p_size_type */
static int le_swig__p_Provider=0; /* handle for Provider */
static int le_swig__p_std__string=0; /* handle for _p_std__string */
/* end vdecl subsection */
/* wrapper section */
ZEND_NAMED_FUNCTION(_wrap_new_MapStringString__SWIG_0) {
  std::map< std::string,std::string > *result = 0 ;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 0) {
    WRONG_PARAM_COUNT;
  }
  
  {
    try {
      result = (std::map< std::string,std::string > *)new std::map< std::string,std::string >();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  SWIG_SetPointerZval(return_value, (void *)result, SWIGTYPE_p_std__mapT_std__string_std__string_t, 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_new_MapStringString__SWIG_1) {
  std::map< std::string,std::string > *arg1 = 0 ;
  zval **args[1];
  std::map< std::string,std::string > *result = 0 ;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__mapT_std__string_std__string_t, 0) < 0 || arg1 == NULL) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of new_MapStringString. Expected SWIGTYPE_p_std__mapT_std__string_std__string_t");
    }
  }
  {
    try {
      result = (std::map< std::string,std::string > *)new std::map< std::string,std::string >((std::map< std::string,std::string > const &)*arg1);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  SWIG_SetPointerZval(return_value, (void *)result, SWIGTYPE_p_std__mapT_std__string_std__string_t, 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_new_MapStringString) {
  int argc;
  zval **argv[1];
  
  argc = ZEND_NUM_ARGS();
  zend_get_parameters_array_ex(argc,argv);
  if (argc == 0) {
    _wrap_new_MapStringString__SWIG_0(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
  }
  if (argc == 1) {
    int _v;
    {
      void *tmp;
      _v = (SWIG_ConvertPtr(*argv[0], (void**)&tmp, SWIGTYPE_p_std__mapT_std__string_std__string_t, 0) >= 0);
    }
    if (_v) {
      _wrap_new_MapStringString__SWIG_1(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
    }
  }
  
  SWIG_ErrorCode() = E_ERROR;
  SWIG_ErrorMsg() = "No matching function for overloaded 'new_MapStringString'";
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_MapStringString_size) {
  std::map< std::string,std::string > *arg1 = (std::map< std::string,std::string > *) 0 ;
  zval **args[1];
  unsigned int result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__mapT_std__string_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of MapStringString_size. Expected SWIGTYPE_p_std__mapT_std__string_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (unsigned int)((std::map< std::string,std::string > const *)arg1)->size();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    ZVAL_LONG(return_value,result);
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_MapStringString_clear) {
  std::map< std::string,std::string > *arg1 = (std::map< std::string,std::string > *) 0 ;
  zval **args[1];
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__mapT_std__string_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of MapStringString_clear. Expected SWIGTYPE_p_std__mapT_std__string_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      (arg1)->clear();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_MapStringString_get) {
  std::map< std::string,std::string > *arg1 = (std::map< std::string,std::string > *) 0 ;
  std::string *arg2 = 0 ;
  std::string temp2 ;
  zval **args[2];
  std::string *result = 0 ;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__mapT_std__string_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of MapStringString_get. Expected SWIGTYPE_p_std__mapT_std__string_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  convert_to_string_ex(args[1]);
  temp2.assign(Z_STRVAL_PP(args[1]), Z_STRLEN_PP(args[1]));
  arg2 = &temp2;
  
  {
    try {
      try {
        result = (std::string *) &std_map_Sl_std_string_Sc_std_string_Sg__get(arg1,(std::string const &)*arg2);
      }
      catch(std::out_of_range &_e) {
        (void)_e;
        zend_throw_exception(NULL, const_cast<char*>("C++ std::out_of_range exception thrown"), 0 TSRMLS_CC);
        return;
        
      }
      ;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  ZVAL_STRINGL(return_value, const_cast<char*>(result->data()), result->size(), 1);
  
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_MapStringString_set) {
  std::map< std::string,std::string > *arg1 = (std::map< std::string,std::string > *) 0 ;
  std::string *arg2 = 0 ;
  std::string *arg3 = 0 ;
  std::string temp2 ;
  std::string temp3 ;
  zval **args[3];
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 3 || zend_get_parameters_array_ex(3, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__mapT_std__string_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of MapStringString_set. Expected SWIGTYPE_p_std__mapT_std__string_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  convert_to_string_ex(args[1]);
  temp2.assign(Z_STRVAL_PP(args[1]), Z_STRLEN_PP(args[1]));
  arg2 = &temp2;
  
  
  convert_to_string_ex(args[2]);
  temp3.assign(Z_STRVAL_PP(args[2]), Z_STRLEN_PP(args[2]));
  arg3 = &temp3;
  
  {
    try {
      std_map_Sl_std_string_Sc_std_string_Sg__set(arg1,(std::string const &)*arg2,(std::string const &)*arg3);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_MapStringString_del) {
  std::map< std::string,std::string > *arg1 = (std::map< std::string,std::string > *) 0 ;
  std::string *arg2 = 0 ;
  std::string temp2 ;
  zval **args[2];
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__mapT_std__string_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of MapStringString_del. Expected SWIGTYPE_p_std__mapT_std__string_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  convert_to_string_ex(args[1]);
  temp2.assign(Z_STRVAL_PP(args[1]), Z_STRLEN_PP(args[1]));
  arg2 = &temp2;
  
  {
    try {
      try {
        std_map_Sl_std_string_Sc_std_string_Sg__del(arg1,(std::string const &)*arg2);
      }
      catch(std::out_of_range &_e) {
        (void)_e;
        zend_throw_exception(NULL, const_cast<char*>("C++ std::out_of_range exception thrown"), 0 TSRMLS_CC);
        return;
        
      }
      ;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_MapStringString_has_key) {
  std::map< std::string,std::string > *arg1 = (std::map< std::string,std::string > *) 0 ;
  std::string *arg2 = 0 ;
  std::string temp2 ;
  zval **args[2];
  bool result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__mapT_std__string_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of MapStringString_has_key. Expected SWIGTYPE_p_std__mapT_std__string_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  convert_to_string_ex(args[1]);
  temp2.assign(Z_STRVAL_PP(args[1]), Z_STRLEN_PP(args[1]));
  arg2 = &temp2;
  
  {
    try {
      result = (bool)std_map_Sl_std_string_Sc_std_string_Sg__has_key(arg1,(std::string const &)*arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    ZVAL_BOOL(return_value,(result)?1:0);
  }
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_MapStringString_is_empty) {
  std::map< std::string,std::string > *arg1 = (std::map< std::string,std::string > *) 0 ;
  zval **args[1];
  bool result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__mapT_std__string_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of MapStringString_is_empty. Expected SWIGTYPE_p_std__mapT_std__string_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (bool)std_map_Sl_std_string_Sc_std_string_Sg__is_empty((std::map< std::string,std::string > const *)arg1);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    ZVAL_BOOL(return_value,(result)?1:0);
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


/* This function is designed to be called by the zend list destructors */
/* to typecast and do the actual destruction */
static void __wrap_delete_MapStringString(zend_rsrc_list_entry *rsrc, const char *type_name TSRMLS_DC) {
  swig_object_wrapper *value=(swig_object_wrapper *) rsrc->ptr ;
  void *ptr=value->ptr ;
  int newobject=value->newobject ;
  std::map< std::string,std::string > *arg1 = (std::map< std::string,std::string > *) 0 ;
  
  efree(value);
  if (! newobject) return; /* can't delete it! */
  arg1 = (std::map< std::string,std::string > *)SWIG_ZTS_ConvertResourceData(ptr,type_name,SWIGTYPE_p_std__mapT_std__string_std__string_t TSRMLS_CC);
  if (! arg1) zend_error(E_ERROR, "std::map<(std::string,std::string)> resource already free'd");
  {
    try {
      delete arg1;;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_new_VectorString__SWIG_0) {
  std::vector< std::string > *result = 0 ;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 0) {
    WRONG_PARAM_COUNT;
  }
  
  {
    try {
      result = (std::vector< std::string > *)new std::vector< std::string >();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  SWIG_SetPointerZval(return_value, (void *)result, SWIGTYPE_p_std__vectorT_std__string_t, 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_new_VectorString__SWIG_1) {
  std::vector< std::string >::size_type arg1 ;
  zval **args[1];
  std::vector< std::string > *result = 0 ;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  
  /*@SWIG:C:\Program Files\SWIG\Lib\php\utils.i,7,CONVERT_INT_IN@*/
  convert_to_long_ex(args[0]);
  arg1 = (std::vector< std::string >::size_type) Z_LVAL_PP(args[0]);
  /*@SWIG@*/;
  
  {
    try {
      result = (std::vector< std::string > *)new std::vector< std::string >(arg1);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  SWIG_SetPointerZval(return_value, (void *)result, SWIGTYPE_p_std__vectorT_std__string_t, 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_new_VectorString) {
  int argc;
  zval **argv[1];
  
  argc = ZEND_NUM_ARGS();
  zend_get_parameters_array_ex(argc,argv);
  if (argc == 0) {
    _wrap_new_VectorString__SWIG_0(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
  }
  if (argc == 1) {
    int _v;
    _v = (Z_TYPE_PP(argv[0]) == IS_LONG); 
    if (_v) {
      _wrap_new_VectorString__SWIG_1(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
    }
  }
  
  SWIG_ErrorCode() = E_ERROR;
  SWIG_ErrorMsg() = "No matching function for overloaded 'new_VectorString'";
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_VectorString_size) {
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  zval **args[1];
  std::vector< std::string >::size_type result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__vectorT_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of VectorString_size. Expected SWIGTYPE_p_std__vectorT_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = ((std::vector< std::string > const *)arg1)->size();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    ZVAL_LONG(return_value,result);
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_VectorString_capacity) {
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  zval **args[1];
  std::vector< std::string >::size_type result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__vectorT_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of VectorString_capacity. Expected SWIGTYPE_p_std__vectorT_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = ((std::vector< std::string > const *)arg1)->capacity();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    ZVAL_LONG(return_value,result);
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_VectorString_reserve) {
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::size_type arg2 ;
  zval **args[2];
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__vectorT_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of VectorString_reserve. Expected SWIGTYPE_p_std__vectorT_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  /*@SWIG:C:\Program Files\SWIG\Lib\php\utils.i,7,CONVERT_INT_IN@*/
  convert_to_long_ex(args[1]);
  arg2 = (std::vector< std::string >::size_type) Z_LVAL_PP(args[1]);
  /*@SWIG@*/;
  
  {
    try {
      (arg1)->reserve(arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_VectorString_clear) {
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  zval **args[1];
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__vectorT_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of VectorString_clear. Expected SWIGTYPE_p_std__vectorT_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      (arg1)->clear();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_VectorString_push) {
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::value_type *arg2 = 0 ;
  std::vector< std::string >::value_type temp2 ;
  zval **args[2];
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__vectorT_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of VectorString_push. Expected SWIGTYPE_p_std__vectorT_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  convert_to_string_ex(args[1]);
  temp2.assign(Z_STRVAL_PP(args[1]), Z_STRLEN_PP(args[1]));
  arg2 = &temp2;
  
  {
    try {
      (arg1)->push_back((std::vector< std::string >::value_type const &)*arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_VectorString_is_empty) {
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  zval **args[1];
  bool result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__vectorT_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of VectorString_is_empty. Expected SWIGTYPE_p_std__vectorT_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (bool)std_vector_Sl_std_string_Sg__is_empty((std::vector< std::string > const *)arg1);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    ZVAL_BOOL(return_value,(result)?1:0);
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_VectorString_pop) {
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  zval **args[1];
  std::string result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__vectorT_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of VectorString_pop. Expected SWIGTYPE_p_std__vectorT_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      try {
        result = std_vector_Sl_std_string_Sg__pop(arg1);
      }
      catch(std::out_of_range &_e) {
        (void)_e;
        zend_throw_exception(NULL, const_cast<char*>("C++ std::out_of_range exception thrown"), 0 TSRMLS_CC);
        return;
        
      }
      ;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  ZVAL_STRINGL(return_value, const_cast<char*>((&result)->data()), (&result)->size(), 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_VectorString_get) {
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  int arg2 ;
  zval **args[2];
  std::vector< std::string >::value_type *result = 0 ;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__vectorT_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of VectorString_get. Expected SWIGTYPE_p_std__vectorT_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  /*@SWIG:C:\Program Files\SWIG\Lib\php\utils.i,7,CONVERT_INT_IN@*/
  convert_to_long_ex(args[1]);
  arg2 = (int) Z_LVAL_PP(args[1]);
  /*@SWIG@*/;
  
  {
    try {
      try {
        result = (std::vector< std::string >::value_type *) &std_vector_Sl_std_string_Sg__get(arg1,arg2);
      }
      catch(std::out_of_range &_e) {
        (void)_e;
        zend_throw_exception(NULL, const_cast<char*>("C++ std::out_of_range exception thrown"), 0 TSRMLS_CC);
        return;
        
      }
      ;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  ZVAL_STRINGL(return_value, const_cast<char*>(result->data()), result->size(), 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_VectorString_set) {
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  int arg2 ;
  std::vector< std::string >::value_type *arg3 = 0 ;
  std::vector< std::string >::value_type temp3 ;
  zval **args[3];
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 3 || zend_get_parameters_array_ex(3, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_std__vectorT_std__string_t, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of VectorString_set. Expected SWIGTYPE_p_std__vectorT_std__string_t");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  /*@SWIG:C:\Program Files\SWIG\Lib\php\utils.i,7,CONVERT_INT_IN@*/
  convert_to_long_ex(args[1]);
  arg2 = (int) Z_LVAL_PP(args[1]);
  /*@SWIG@*/;
  
  
  convert_to_string_ex(args[2]);
  temp3.assign(Z_STRVAL_PP(args[2]), Z_STRLEN_PP(args[2]));
  arg3 = &temp3;
  
  {
    try {
      try {
        std_vector_Sl_std_string_Sg__set(arg1,arg2,(std::string const &)*arg3);
      }
      catch(std::out_of_range &_e) {
        (void)_e;
        zend_throw_exception(NULL, const_cast<char*>("C++ std::out_of_range exception thrown"), 0 TSRMLS_CC);
        return;
        
      }
      ;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


/* This function is designed to be called by the zend list destructors */
/* to typecast and do the actual destruction */
static void __wrap_delete_VectorString(zend_rsrc_list_entry *rsrc, const char *type_name TSRMLS_DC) {
  swig_object_wrapper *value=(swig_object_wrapper *) rsrc->ptr ;
  void *ptr=value->ptr ;
  int newobject=value->newobject ;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  
  efree(value);
  if (! newobject) return; /* can't delete it! */
  arg1 = (std::vector< std::string > *)SWIG_ZTS_ConvertResourceData(ptr,type_name,SWIGTYPE_p_std__vectorT_std__string_t TSRMLS_CC);
  if (! arg1) zend_error(E_ERROR, "std::vector<(std::string)> resource already free'd");
  {
    try {
      delete arg1;;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_provider_get) {
  Provider *result = 0 ;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 0) {
    WRONG_PARAM_COUNT;
  }
  
  result = (Provider *)provider;
  
  SWIG_SetPointerZval(return_value, (void *)result, SWIGTYPE_p_Provider, 0);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


/* This function is designed to be called by the zend list destructors */
/* to typecast and do the actual destruction */
static void __wrap_delete_Match(zend_rsrc_list_entry *rsrc, const char *type_name TSRMLS_DC) {
  swig_object_wrapper *value=(swig_object_wrapper *) rsrc->ptr ;
  void *ptr=value->ptr ;
  int newobject=value->newobject ;
  Match *arg1 = (Match *) 0 ;
  
  efree(value);
  if (! newobject) return; /* can't delete it! */
  arg1 = (Match *)SWIG_ZTS_ConvertResourceData(ptr,type_name,SWIGTYPE_p_Match TSRMLS_CC);
  if (! arg1) zend_error(E_ERROR, "Match resource already free'd");
  {
    try {
      delete arg1;;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Match_getValues__SWIG_0) {
  Match *arg1 = (Match *) 0 ;
  char *arg2 = (char *) 0 ;
  zval **args[2];
  std::vector< std::string > result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Match, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Match_getValues. Expected SWIGTYPE_p_Match");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  /*@SWIG:C:\Program Files\SWIG\Lib\php\utils.i,62,CONVERT_STRING_IN@*/
  if ((*args[1])->type==IS_NULL) {
    arg2 = (char *) 0;
  } else {
    convert_to_string_ex(args[1]);
    arg2 = (char *) Z_STRVAL_PP(args[1]);
  }
  /*@SWIG@*/;
  
  {
    try {
      result = (arg1)->getValues((char const *)arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    std::vector< std::string > * resultobj = new std::vector< std::string >((const std::vector< std::string > &) result);
    SWIG_SetPointerZval(return_value, (void *)resultobj, SWIGTYPE_p_std__vectorT_std__string_t, 1);
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Match_getValues__SWIG_1) {
  Match *arg1 = (Match *) 0 ;
  std::string *arg2 = 0 ;
  std::string temp2 ;
  zval **args[2];
  std::vector< std::string > result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Match, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Match_getValues. Expected SWIGTYPE_p_Match");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  convert_to_string_ex(args[1]);
  temp2.assign(Z_STRVAL_PP(args[1]), Z_STRLEN_PP(args[1]));
  arg2 = &temp2;
  
  {
    try {
      result = (arg1)->getValues(*arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    std::vector< std::string > * resultobj = new std::vector< std::string >((const std::vector< std::string > &) result);
    SWIG_SetPointerZval(return_value, (void *)resultobj, SWIGTYPE_p_std__vectorT_std__string_t, 1);
  }
  
  ZVAL_STRINGL(*(args[1]), const_cast<char*>(arg2->data()), arg2->size(), 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Match_getValues__SWIG_2) {
  Match *arg1 = (Match *) 0 ;
  int arg2 ;
  zval **args[2];
  std::vector< std::string > result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Match, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Match_getValues. Expected SWIGTYPE_p_Match");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  /*@SWIG:C:\Program Files\SWIG\Lib\php\utils.i,7,CONVERT_INT_IN@*/
  convert_to_long_ex(args[1]);
  arg2 = (int) Z_LVAL_PP(args[1]);
  /*@SWIG@*/;
  
  {
    try {
      result = (arg1)->getValues(arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    std::vector< std::string > * resultobj = new std::vector< std::string >((const std::vector< std::string > &) result);
    SWIG_SetPointerZval(return_value, (void *)resultobj, SWIGTYPE_p_std__vectorT_std__string_t, 1);
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Match_getValues) {
  int argc;
  zval **argv[2];
  
  argc = ZEND_NUM_ARGS();
  zend_get_parameters_array_ex(argc,argv);
  if (argc == 2) {
    int _v;
    {
      void *tmp;
      _v = (SWIG_ConvertPtr(*argv[0], (void**)&tmp, SWIGTYPE_p_Match, 0) >= 0);
    }
    if (_v) {
      {
        void *tmp;
        _v = (SWIG_ConvertPtr(*argv[1], (void**)&tmp, SWIGTYPE_p_std__string, 0) >= 0);
      }
      if (_v) {
        _wrap_Match_getValues__SWIG_1(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      void *tmp;
      _v = (SWIG_ConvertPtr(*argv[0], (void**)&tmp, SWIGTYPE_p_Match, 0) >= 0);
    }
    if (_v) {
      _v = (Z_TYPE_PP(argv[1]) == IS_LONG); 
      if (_v) {
        _wrap_Match_getValues__SWIG_2(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      void *tmp;
      _v = (SWIG_ConvertPtr(*argv[0], (void**)&tmp, SWIGTYPE_p_Match, 0) >= 0);
    }
    if (_v) {
      _v = (Z_TYPE_PP(argv[1]) == IS_STRING); 
      if (_v) {
        _wrap_Match_getValues__SWIG_0(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
      }
    }
  }
  
  SWIG_ErrorCode() = E_ERROR;
  SWIG_ErrorMsg() = "No matching function for overloaded 'Match_getValues'";
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Match_getValue__SWIG_0) {
  Match *arg1 = (Match *) 0 ;
  char *arg2 = (char *) 0 ;
  zval **args[2];
  std::string result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Match, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Match_getValue. Expected SWIGTYPE_p_Match");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  /*@SWIG:C:\Program Files\SWIG\Lib\php\utils.i,62,CONVERT_STRING_IN@*/
  if ((*args[1])->type==IS_NULL) {
    arg2 = (char *) 0;
  } else {
    convert_to_string_ex(args[1]);
    arg2 = (char *) Z_STRVAL_PP(args[1]);
  }
  /*@SWIG@*/;
  
  {
    try {
      result = (arg1)->getValue((char const *)arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  ZVAL_STRINGL(return_value, const_cast<char*>((&result)->data()), (&result)->size(), 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Match_getValue__SWIG_1) {
  Match *arg1 = (Match *) 0 ;
  std::string *arg2 = 0 ;
  std::string temp2 ;
  zval **args[2];
  std::string result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Match, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Match_getValue. Expected SWIGTYPE_p_Match");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  convert_to_string_ex(args[1]);
  temp2.assign(Z_STRVAL_PP(args[1]), Z_STRLEN_PP(args[1]));
  arg2 = &temp2;
  
  {
    try {
      result = (arg1)->getValue(*arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  ZVAL_STRINGL(return_value, const_cast<char*>((&result)->data()), (&result)->size(), 1);
  
  
  ZVAL_STRINGL(*(args[1]), const_cast<char*>(arg2->data()), arg2->size(), 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Match_getValue__SWIG_2) {
  Match *arg1 = (Match *) 0 ;
  int arg2 ;
  zval **args[2];
  std::string result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Match, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Match_getValue. Expected SWIGTYPE_p_Match");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  /*@SWIG:C:\Program Files\SWIG\Lib\php\utils.i,7,CONVERT_INT_IN@*/
  convert_to_long_ex(args[1]);
  arg2 = (int) Z_LVAL_PP(args[1]);
  /*@SWIG@*/;
  
  {
    try {
      result = (arg1)->getValue(arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  ZVAL_STRINGL(return_value, const_cast<char*>((&result)->data()), (&result)->size(), 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Match_getValue) {
  int argc;
  zval **argv[2];
  
  argc = ZEND_NUM_ARGS();
  zend_get_parameters_array_ex(argc,argv);
  if (argc == 2) {
    int _v;
    {
      void *tmp;
      _v = (SWIG_ConvertPtr(*argv[0], (void**)&tmp, SWIGTYPE_p_Match, 0) >= 0);
    }
    if (_v) {
      {
        void *tmp;
        _v = (SWIG_ConvertPtr(*argv[1], (void**)&tmp, SWIGTYPE_p_std__string, 0) >= 0);
      }
      if (_v) {
        _wrap_Match_getValue__SWIG_1(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      void *tmp;
      _v = (SWIG_ConvertPtr(*argv[0], (void**)&tmp, SWIGTYPE_p_Match, 0) >= 0);
    }
    if (_v) {
      _v = (Z_TYPE_PP(argv[1]) == IS_LONG); 
      if (_v) {
        _wrap_Match_getValue__SWIG_2(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      void *tmp;
      _v = (SWIG_ConvertPtr(*argv[0], (void**)&tmp, SWIGTYPE_p_Match, 0) >= 0);
    }
    if (_v) {
      _v = (Z_TYPE_PP(argv[1]) == IS_STRING); 
      if (_v) {
        _wrap_Match_getValue__SWIG_0(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
      }
    }
  }
  
  SWIG_ErrorCode() = E_ERROR;
  SWIG_ErrorMsg() = "No matching function for overloaded 'Match_getValue'";
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Match_getDeviceId) {
  Match *arg1 = (Match *) 0 ;
  zval **args[1];
  std::string result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Match, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Match_getDeviceId. Expected SWIGTYPE_p_Match");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (arg1)->getDeviceId();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  ZVAL_STRINGL(return_value, const_cast<char*>((&result)->data()), (&result)->size(), 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Match_getRank) {
  Match *arg1 = (Match *) 0 ;
  zval **args[1];
  int result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Match, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Match_getRank. Expected SWIGTYPE_p_Match");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (int)(arg1)->getRank();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    ZVAL_LONG(return_value,result);
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Match_getDifference) {
  Match *arg1 = (Match *) 0 ;
  zval **args[1];
  int result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Match, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Match_getDifference. Expected SWIGTYPE_p_Match");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (int)(arg1)->getDifference();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    ZVAL_LONG(return_value,result);
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Match_getMethod) {
  Match *arg1 = (Match *) 0 ;
  zval **args[1];
  int result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Match, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Match_getMethod. Expected SWIGTYPE_p_Match");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (int)(arg1)->getMethod();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    ZVAL_LONG(return_value,result);
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Match_getUserAgent) {
  Match *arg1 = (Match *) 0 ;
  zval **args[1];
  std::string result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Match, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Match_getUserAgent. Expected SWIGTYPE_p_Match");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (arg1)->getUserAgent();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  ZVAL_STRINGL(return_value, const_cast<char*>((&result)->data()), (&result)->size(), 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_new_Provider__SWIG_0) {
  std::string *arg1 = 0 ;
  std::string temp1 ;
  zval **args[1];
  Provider *result = 0 ;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  
  convert_to_string_ex(args[0]);
  temp1.assign(Z_STRVAL_PP(args[0]), Z_STRLEN_PP(args[0]));
  arg1 = &temp1;
  
  {
    try {
      result = (Provider *)new Provider((std::string const &)*arg1);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  SWIG_SetPointerZval(return_value, (void *)result, SWIGTYPE_p_Provider, 1);
  
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_new_Provider__SWIG_1) {
  std::string *arg1 = 0 ;
  std::string *arg2 = 0 ;
  std::string temp1 ;
  std::string temp2 ;
  zval **args[2];
  Provider *result = 0 ;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  
  convert_to_string_ex(args[0]);
  temp1.assign(Z_STRVAL_PP(args[0]), Z_STRLEN_PP(args[0]));
  arg1 = &temp1;
  
  
  convert_to_string_ex(args[1]);
  temp2.assign(Z_STRVAL_PP(args[1]), Z_STRLEN_PP(args[1]));
  arg2 = &temp2;
  
  {
    try {
      result = (Provider *)new Provider((std::string const &)*arg1,(std::string const &)*arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  SWIG_SetPointerZval(return_value, (void *)result, SWIGTYPE_p_Provider, 1);
  
  
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_new_Provider__SWIG_2) {
  std::string *arg1 = 0 ;
  std::vector< std::string > *arg2 = 0 ;
  std::string temp1 ;
  zval **args[2];
  Provider *result = 0 ;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  
  convert_to_string_ex(args[0]);
  temp1.assign(Z_STRVAL_PP(args[0]), Z_STRLEN_PP(args[0]));
  arg1 = &temp1;
  
  {
    if(SWIG_ConvertPtr(*args[1], (void **) &arg2, SWIGTYPE_p_std__vectorT_std__string_t, 0) < 0 || arg2 == NULL) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 2 of new_Provider. Expected SWIGTYPE_p_std__vectorT_std__string_t");
    }
  }
  {
    try {
      result = (Provider *)new Provider((std::string const &)*arg1,*arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  SWIG_SetPointerZval(return_value, (void *)result, SWIGTYPE_p_Provider, 1);
  
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_new_Provider) {
  int argc;
  zval **argv[2];
  
  argc = ZEND_NUM_ARGS();
  zend_get_parameters_array_ex(argc,argv);
  if (argc == 1) {
    int _v;
    
    _v = ( Z_TYPE_PP(argv[0]) == IS_STRING ) ? 1 : 0;
    
    if (_v) {
      _wrap_new_Provider__SWIG_0(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
    }
  }
  if (argc == 2) {
    int _v;
    
    _v = ( Z_TYPE_PP(argv[0]) == IS_STRING ) ? 1 : 0;
    
    if (_v) {
      {
        void *tmp;
        _v = (SWIG_ConvertPtr(*argv[1], (void**)&tmp, SWIGTYPE_p_std__vectorT_std__string_t, 0) >= 0);
      }
      if (_v) {
        _wrap_new_Provider__SWIG_2(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
      }
    }
  }
  if (argc == 2) {
    int _v;
    
    _v = ( Z_TYPE_PP(argv[0]) == IS_STRING ) ? 1 : 0;
    
    if (_v) {
      _v = ( Z_TYPE_PP(argv[1]) == IS_STRING ) ? 1 : 0;
      
      if (_v) {
        _wrap_new_Provider__SWIG_1(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
      }
    }
  }
  
  SWIG_ErrorCode() = E_ERROR;
  SWIG_ErrorMsg() = "No matching function for overloaded 'new_Provider'";
  SWIG_FAIL(TSRMLS_C);
}


/* This function is designed to be called by the zend list destructors */
/* to typecast and do the actual destruction */
static void __wrap_delete_Provider(zend_rsrc_list_entry *rsrc, const char *type_name TSRMLS_DC) {
  swig_object_wrapper *value=(swig_object_wrapper *) rsrc->ptr ;
  void *ptr=value->ptr ;
  int newobject=value->newobject ;
  Provider *arg1 = (Provider *) 0 ;
  
  efree(value);
  if (! newobject) return; /* can't delete it! */
  arg1 = (Provider *)SWIG_ZTS_ConvertResourceData(ptr,type_name,SWIGTYPE_p_Provider TSRMLS_CC);
  if (! arg1) zend_error(E_ERROR, "Provider resource already free'd");
  {
    try {
      delete arg1;;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Provider_getHttpHeaders) {
  Provider *arg1 = (Provider *) 0 ;
  zval **args[1];
  std::vector< std::string > result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Provider, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Provider_getHttpHeaders. Expected SWIGTYPE_p_Provider");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (arg1)->getHttpHeaders();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    std::vector< std::string > * resultobj = new std::vector< std::string >((const std::vector< std::string > &) result);
    SWIG_SetPointerZval(return_value, (void *)resultobj, SWIGTYPE_p_std__vectorT_std__string_t, 1);
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Provider_getAvailableProperties) {
  Provider *arg1 = (Provider *) 0 ;
  zval **args[1];
  std::vector< std::string > result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Provider, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Provider_getAvailableProperties. Expected SWIGTYPE_p_Provider");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (arg1)->getAvailableProperties();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    std::vector< std::string > * resultobj = new std::vector< std::string >((const std::vector< std::string > &) result);
    SWIG_SetPointerZval(return_value, (void *)resultobj, SWIGTYPE_p_std__vectorT_std__string_t, 1);
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Provider_getDataSetName) {
  Provider *arg1 = (Provider *) 0 ;
  zval **args[1];
  std::string result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Provider, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Provider_getDataSetName. Expected SWIGTYPE_p_Provider");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (arg1)->getDataSetName();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  ZVAL_STRINGL(return_value, const_cast<char*>((&result)->data()), (&result)->size(), 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Provider_getDataSetFormat) {
  Provider *arg1 = (Provider *) 0 ;
  zval **args[1];
  std::string result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Provider, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Provider_getDataSetFormat. Expected SWIGTYPE_p_Provider");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (arg1)->getDataSetFormat();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  ZVAL_STRINGL(return_value, const_cast<char*>((&result)->data()), (&result)->size(), 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Provider_getDataSetPublishedDate) {
  Provider *arg1 = (Provider *) 0 ;
  zval **args[1];
  std::string result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Provider, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Provider_getDataSetPublishedDate. Expected SWIGTYPE_p_Provider");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (arg1)->getDataSetPublishedDate();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  ZVAL_STRINGL(return_value, const_cast<char*>((&result)->data()), (&result)->size(), 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Provider_getDataSetNextUpdateDate) {
  Provider *arg1 = (Provider *) 0 ;
  zval **args[1];
  std::string result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Provider, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Provider_getDataSetNextUpdateDate. Expected SWIGTYPE_p_Provider");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (arg1)->getDataSetNextUpdateDate();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  ZVAL_STRINGL(return_value, const_cast<char*>((&result)->data()), (&result)->size(), 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Provider_getDataSetSignatureCount) {
  Provider *arg1 = (Provider *) 0 ;
  zval **args[1];
  int result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Provider, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Provider_getDataSetSignatureCount. Expected SWIGTYPE_p_Provider");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (int)(arg1)->getDataSetSignatureCount();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    ZVAL_LONG(return_value,result);
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Provider_getDataSetDeviceCombinations) {
  Provider *arg1 = (Provider *) 0 ;
  zval **args[1];
  int result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Provider, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Provider_getDataSetDeviceCombinations. Expected SWIGTYPE_p_Provider");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    try {
      result = (int)(arg1)->getDataSetDeviceCombinations();;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  {
    ZVAL_LONG(return_value,result);
  }
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Provider_getMatch__SWIG_0) {
  Provider *arg1 = (Provider *) 0 ;
  std::string *arg2 = 0 ;
  std::string temp2 ;
  zval **args[2];
  Match *result = 0 ;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Provider, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Provider_getMatch. Expected SWIGTYPE_p_Provider");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  convert_to_string_ex(args[1]);
  temp2.assign(Z_STRVAL_PP(args[1]), Z_STRLEN_PP(args[1]));
  arg2 = &temp2;
  
  {
    try {
      result = (Match *)(arg1)->getMatch((std::string const &)*arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  SWIG_SetPointerZval(return_value, (void *)result, SWIGTYPE_p_Match, 1);
  
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Provider_getMatch__SWIG_1) {
  Provider *arg1 = (Provider *) 0 ;
  std::map< std::string,std::string > *arg2 = 0 ;
  zval **args[2];
  Match *result = 0 ;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Provider, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Provider_getMatch. Expected SWIGTYPE_p_Provider");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    if(SWIG_ConvertPtr(*args[1], (void **) &arg2, SWIGTYPE_p_std__mapT_std__string_std__string_t, 0) < 0 || arg2 == NULL) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 2 of Provider_getMatch. Expected SWIGTYPE_p_std__mapT_std__string_std__string_t");
    }
  }
  {
    try {
      result = (Match *)(arg1)->getMatch((std::map< std::string,std::string > const &)*arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  SWIG_SetPointerZval(return_value, (void *)result, SWIGTYPE_p_Match, 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Provider_getMatch) {
  int argc;
  zval **argv[2];
  
  argc = ZEND_NUM_ARGS();
  zend_get_parameters_array_ex(argc,argv);
  if (argc == 2) {
    int _v;
    {
      void *tmp;
      _v = (SWIG_ConvertPtr(*argv[0], (void**)&tmp, SWIGTYPE_p_Provider, 0) >= 0);
    }
    if (_v) {
      {
        void *tmp;
        _v = (SWIG_ConvertPtr(*argv[1], (void**)&tmp, SWIGTYPE_p_std__mapT_std__string_std__string_t, 0) >= 0);
      }
      if (_v) {
        _wrap_Provider_getMatch__SWIG_1(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      void *tmp;
      _v = (SWIG_ConvertPtr(*argv[0], (void**)&tmp, SWIGTYPE_p_Provider, 0) >= 0);
    }
    if (_v) {
      _v = ( Z_TYPE_PP(argv[1]) == IS_STRING ) ? 1 : 0;
      
      if (_v) {
        _wrap_Provider_getMatch__SWIG_0(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
      }
    }
  }
  
  SWIG_ErrorCode() = E_ERROR;
  SWIG_ErrorMsg() = "No matching function for overloaded 'Provider_getMatch'";
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Provider_getMatchJson__SWIG_0) {
  Provider *arg1 = (Provider *) 0 ;
  std::string *arg2 = 0 ;
  std::string temp2 ;
  zval **args[2];
  std::string result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Provider, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Provider_getMatchJson. Expected SWIGTYPE_p_Provider");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  
  convert_to_string_ex(args[1]);
  temp2.assign(Z_STRVAL_PP(args[1]), Z_STRLEN_PP(args[1]));
  arg2 = &temp2;
  
  {
    try {
      result = (arg1)->getMatchJson((std::string const &)*arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  ZVAL_STRINGL(return_value, const_cast<char*>((&result)->data()), (&result)->size(), 1);
  
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Provider_getMatchJson__SWIG_1) {
  Provider *arg1 = (Provider *) 0 ;
  std::map< std::string,std::string > *arg2 = 0 ;
  zval **args[2];
  std::string result;
  
  SWIG_ResetError(TSRMLS_C);
  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {
    WRONG_PARAM_COUNT;
  }
  
  {
    if(SWIG_ConvertPtr(*args[0], (void **) &arg1, SWIGTYPE_p_Provider, 0) < 0) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 1 of Provider_getMatchJson. Expected SWIGTYPE_p_Provider");
    }
  }
  if(!arg1) SWIG_PHP_Error(E_ERROR, "this pointer is NULL");
  {
    if(SWIG_ConvertPtr(*args[1], (void **) &arg2, SWIGTYPE_p_std__mapT_std__string_std__string_t, 0) < 0 || arg2 == NULL) {
      SWIG_PHP_Error(E_ERROR, "Type error in argument 2 of Provider_getMatchJson. Expected SWIGTYPE_p_std__mapT_std__string_std__string_t");
    }
  }
  {
    try {
      result = (arg1)->getMatchJson((std::map< std::string,std::string > const &)*arg2);;
    }
    catch(runtime_error& e) {
      SWIG_exception(SWIG_RuntimeError, e.what());
    }
    catch(invalid_argument& e) {
      SWIG_exception(SWIG_ValueError, e.what());
    }
  }
  
  ZVAL_STRINGL(return_value, const_cast<char*>((&result)->data()), (&result)->size(), 1);
  
  return;
fail:
  SWIG_FAIL(TSRMLS_C);
}


ZEND_NAMED_FUNCTION(_wrap_Provider_getMatchJson) {
  int argc;
  zval **argv[2];
  
  argc = ZEND_NUM_ARGS();
  zend_get_parameters_array_ex(argc,argv);
  if (argc == 2) {
    int _v;
    {
      void *tmp;
      _v = (SWIG_ConvertPtr(*argv[0], (void**)&tmp, SWIGTYPE_p_Provider, 0) >= 0);
    }
    if (_v) {
      {
        void *tmp;
        _v = (SWIG_ConvertPtr(*argv[1], (void**)&tmp, SWIGTYPE_p_std__mapT_std__string_std__string_t, 0) >= 0);
      }
      if (_v) {
        _wrap_Provider_getMatchJson__SWIG_1(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      void *tmp;
      _v = (SWIG_ConvertPtr(*argv[0], (void**)&tmp, SWIGTYPE_p_Provider, 0) >= 0);
    }
    if (_v) {
      _v = ( Z_TYPE_PP(argv[1]) == IS_STRING ) ? 1 : 0;
      
      if (_v) {
        _wrap_Provider_getMatchJson__SWIG_0(INTERNAL_FUNCTION_PARAM_PASSTHRU); return;
      }
    }
  }
  
  SWIG_ErrorCode() = E_ERROR;
  SWIG_ErrorMsg() = "No matching function for overloaded 'Provider_getMatchJson'";
  SWIG_FAIL(TSRMLS_C);
}


static ZEND_RSRC_DTOR_FUNC(_wrap_destroy_p_key_type) {
  /* No destructor for simple type _p_key_type */
  efree(rsrc->ptr);
}
static ZEND_RSRC_DTOR_FUNC(_wrap_destroy_p_mapped_type) {
  /* No destructor for simple type _p_mapped_type */
  efree(rsrc->ptr);
}
static ZEND_RSRC_DTOR_FUNC(_wrap_destroy_p_difference_type) {
  /* No destructor for simple type _p_difference_type */
  efree(rsrc->ptr);
}
static ZEND_RSRC_DTOR_FUNC(_wrap_destroy_p_std__mapT_std__string_std__string_t) {
  __wrap_delete_MapStringString(rsrc, SWIGTYPE_p_std__mapT_std__string_std__string_t->name TSRMLS_CC);
}
static ZEND_RSRC_DTOR_FUNC(_wrap_destroy_p_value_type) {
  /* No destructor for simple type _p_value_type */
  efree(rsrc->ptr);
}
static ZEND_RSRC_DTOR_FUNC(_wrap_destroy_p_std__vectorT_std__string_t) {
  __wrap_delete_VectorString(rsrc, SWIGTYPE_p_std__vectorT_std__string_t->name TSRMLS_CC);
}
static ZEND_RSRC_DTOR_FUNC(_wrap_destroy_p_Match) {
  __wrap_delete_Match(rsrc, SWIGTYPE_p_Match->name TSRMLS_CC);
}
static ZEND_RSRC_DTOR_FUNC(_wrap_destroy_p_size_type) {
  /* No destructor for simple type _p_size_type */
  efree(rsrc->ptr);
}
static ZEND_RSRC_DTOR_FUNC(_wrap_destroy_p_Provider) {
  __wrap_delete_Provider(rsrc, SWIGTYPE_p_Provider->name TSRMLS_CC);
}
static ZEND_RSRC_DTOR_FUNC(_wrap_destroy_p_std__string) {
  /* No destructor for simple type _p_std__string */
  efree(rsrc->ptr);
}
/* end wrapper section */
/* class entry subsection */


/* arginfo subsection */
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_new_mapstringstring, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_mapstringstring_size, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_mapstringstring_clear, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_mapstringstring_get, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_mapstringstring_set, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_mapstringstring_del, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_mapstringstring_has_key, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_mapstringstring_is_empty, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_new_vectorstring, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_vectorstring_size, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_vectorstring_capacity, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_vectorstring_reserve, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_vectorstring_clear, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_vectorstring_push, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_vectorstring_is_empty, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_vectorstring_pop, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_vectorstring_get, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_vectorstring_set, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_provider_get, 0, 0, 0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_match_getvalues, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_match_getvalue, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_match_getdeviceid, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_match_getrank, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_match_getdifference, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_match_getmethod, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_match_getuseragent, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_new_provider, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_provider_gethttpheaders, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_provider_getavailableproperties, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_provider_getdatasetname, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_provider_getdatasetformat, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_provider_getdatasetpublisheddate, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_provider_getdatasetnextupdatedate, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_provider_getdatasetsignaturecount, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_provider_getdatasetdevicecombinations, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_provider_getmatch, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_provider_getmatchjson, 0, 0, 0)
 ZEND_ARG_PASS_INFO(0)
 ZEND_ARG_PASS_INFO(0)
ZEND_END_ARG_INFO()


/* entry subsection */
/* Every non-class user visible function must have an entry here */
static zend_function_entry FiftyOneDegreesTrieV3_functions[] = {
 SWIG_ZEND_NAMED_FE(new_mapstringstring,_wrap_new_MapStringString,swig_arginfo_new_mapstringstring)
 SWIG_ZEND_NAMED_FE(mapstringstring_size,_wrap_MapStringString_size,swig_arginfo_mapstringstring_size)
 SWIG_ZEND_NAMED_FE(mapstringstring_clear,_wrap_MapStringString_clear,swig_arginfo_mapstringstring_clear)
 SWIG_ZEND_NAMED_FE(mapstringstring_get,_wrap_MapStringString_get,swig_arginfo_mapstringstring_get)
 SWIG_ZEND_NAMED_FE(mapstringstring_set,_wrap_MapStringString_set,swig_arginfo_mapstringstring_set)
 SWIG_ZEND_NAMED_FE(mapstringstring_del,_wrap_MapStringString_del,swig_arginfo_mapstringstring_del)
 SWIG_ZEND_NAMED_FE(mapstringstring_has_key,_wrap_MapStringString_has_key,swig_arginfo_mapstringstring_has_key)
 SWIG_ZEND_NAMED_FE(mapstringstring_is_empty,_wrap_MapStringString_is_empty,swig_arginfo_mapstringstring_is_empty)
 SWIG_ZEND_NAMED_FE(new_vectorstring,_wrap_new_VectorString,swig_arginfo_new_vectorstring)
 SWIG_ZEND_NAMED_FE(vectorstring_size,_wrap_VectorString_size,swig_arginfo_vectorstring_size)
 SWIG_ZEND_NAMED_FE(vectorstring_capacity,_wrap_VectorString_capacity,swig_arginfo_vectorstring_capacity)
 SWIG_ZEND_NAMED_FE(vectorstring_reserve,_wrap_VectorString_reserve,swig_arginfo_vectorstring_reserve)
 SWIG_ZEND_NAMED_FE(vectorstring_clear,_wrap_VectorString_clear,swig_arginfo_vectorstring_clear)
 SWIG_ZEND_NAMED_FE(vectorstring_push,_wrap_VectorString_push,swig_arginfo_vectorstring_push)
 SWIG_ZEND_NAMED_FE(vectorstring_is_empty,_wrap_VectorString_is_empty,swig_arginfo_vectorstring_is_empty)
 SWIG_ZEND_NAMED_FE(vectorstring_pop,_wrap_VectorString_pop,swig_arginfo_vectorstring_pop)
 SWIG_ZEND_NAMED_FE(vectorstring_get,_wrap_VectorString_get,swig_arginfo_vectorstring_get)
 SWIG_ZEND_NAMED_FE(vectorstring_set,_wrap_VectorString_set,swig_arginfo_vectorstring_set)
 SWIG_ZEND_NAMED_FE(provider_get,_wrap_provider_get,swig_arginfo_provider_get)
 SWIG_ZEND_NAMED_FE(match_getvalues,_wrap_Match_getValues,swig_arginfo_match_getvalues)
 SWIG_ZEND_NAMED_FE(match_getvalue,_wrap_Match_getValue,swig_arginfo_match_getvalue)
 SWIG_ZEND_NAMED_FE(match_getdeviceid,_wrap_Match_getDeviceId,swig_arginfo_match_getdeviceid)
 SWIG_ZEND_NAMED_FE(match_getrank,_wrap_Match_getRank,swig_arginfo_match_getrank)
 SWIG_ZEND_NAMED_FE(match_getdifference,_wrap_Match_getDifference,swig_arginfo_match_getdifference)
 SWIG_ZEND_NAMED_FE(match_getmethod,_wrap_Match_getMethod,swig_arginfo_match_getmethod)
 SWIG_ZEND_NAMED_FE(match_getuseragent,_wrap_Match_getUserAgent,swig_arginfo_match_getuseragent)
 SWIG_ZEND_NAMED_FE(new_provider,_wrap_new_Provider,swig_arginfo_new_provider)
 SWIG_ZEND_NAMED_FE(provider_gethttpheaders,_wrap_Provider_getHttpHeaders,swig_arginfo_provider_gethttpheaders)
 SWIG_ZEND_NAMED_FE(provider_getavailableproperties,_wrap_Provider_getAvailableProperties,swig_arginfo_provider_getavailableproperties)
 SWIG_ZEND_NAMED_FE(provider_getdatasetname,_wrap_Provider_getDataSetName,swig_arginfo_provider_getdatasetname)
 SWIG_ZEND_NAMED_FE(provider_getdatasetformat,_wrap_Provider_getDataSetFormat,swig_arginfo_provider_getdatasetformat)
 SWIG_ZEND_NAMED_FE(provider_getdatasetpublisheddate,_wrap_Provider_getDataSetPublishedDate,swig_arginfo_provider_getdatasetpublisheddate)
 SWIG_ZEND_NAMED_FE(provider_getdatasetnextupdatedate,_wrap_Provider_getDataSetNextUpdateDate,swig_arginfo_provider_getdatasetnextupdatedate)
 SWIG_ZEND_NAMED_FE(provider_getdatasetsignaturecount,_wrap_Provider_getDataSetSignatureCount,swig_arginfo_provider_getdatasetsignaturecount)
 SWIG_ZEND_NAMED_FE(provider_getdatasetdevicecombinations,_wrap_Provider_getDataSetDeviceCombinations,swig_arginfo_provider_getdatasetdevicecombinations)
 SWIG_ZEND_NAMED_FE(provider_getmatch,_wrap_Provider_getMatch,swig_arginfo_provider_getmatch)
 SWIG_ZEND_NAMED_FE(provider_getmatchjson,_wrap_Provider_getMatchJson,swig_arginfo_provider_getmatchjson)
 SWIG_ZEND_NAMED_FE(swig_FiftyOneDegreesTrieV3_alter_newobject,_wrap_swig_FiftyOneDegreesTrieV3_alter_newobject,NULL)
 SWIG_ZEND_NAMED_FE(swig_FiftyOneDegreesTrieV3_get_newobject,_wrap_swig_FiftyOneDegreesTrieV3_get_newobject,NULL)
{NULL, NULL, NULL}
};

/* init section */
#if ZEND_MODULE_API_NO <= 20090626
#undef ZEND_MODULE_BUILD_ID
#define ZEND_MODULE_BUILD_ID (char*)"API" ZEND_TOSTR(ZEND_MODULE_API_NO) ZEND_BUILD_TS ZEND_BUILD_DEBUG ZEND_BUILD_SYSTEM ZEND_BUILD_EXTRA
#endif
zend_module_entry FiftyOneDegreesTrieV3_module_entry = {
    STANDARD_MODULE_HEADER,
    (char*)"FiftyOneDegreesTrieV3",
    FiftyOneDegreesTrieV3_functions,
    PHP_MINIT(FiftyOneDegreesTrieV3),
    PHP_MSHUTDOWN(FiftyOneDegreesTrieV3),
    PHP_RINIT(FiftyOneDegreesTrieV3),
    PHP_RSHUTDOWN(FiftyOneDegreesTrieV3),
    PHP_MINFO(FiftyOneDegreesTrieV3),
    NO_VERSION_YET,
    STANDARD_MODULE_PROPERTIES
};
zend_module_entry* SWIG_module_entry = &FiftyOneDegreesTrieV3_module_entry;

#ifdef __cplusplus
extern "C" {
#endif
SWIGEXPORT zend_module_entry *get_module(void) { return &FiftyOneDegreesTrieV3_module_entry; }
#ifdef __cplusplus
}
#endif

#define SWIG_php_minit PHP_MINIT_FUNCTION(FiftyOneDegreesTrieV3)
/* -----------------------------------------------------------------------------
 * Type initialization:
 * This problem is tough by the requirement that no dynamic
 * memory is used. Also, since swig_type_info structures store pointers to
 * swig_cast_info structures and swig_cast_info structures store pointers back
 * to swig_type_info structures, we need some lookup code at initialization.
 * The idea is that swig generates all the structures that are needed.
 * The runtime then collects these partially filled structures.
 * The SWIG_InitializeModule function takes these initial arrays out of
 * swig_module, and does all the lookup, filling in the swig_module.types
 * array with the correct data and linking the correct swig_cast_info
 * structures together.
 *
 * The generated swig_type_info structures are assigned statically to an initial
 * array. We just loop through that array, and handle each type individually.
 * First we lookup if this type has been already loaded, and if so, use the
 * loaded structure instead of the generated one. Then we have to fill in the
 * cast linked list. The cast data is initially stored in something like a
 * two-dimensional array. Each row corresponds to a type (there are the same
 * number of rows as there are in the swig_type_initial array). Each entry in
 * a column is one of the swig_cast_info structures for that type.
 * The cast_initial array is actually an array of arrays, because each row has
 * a variable number of columns. So to actually build the cast linked list,
 * we find the array of casts associated with the type, and loop through it
 * adding the casts to the list. The one last trick we need to do is making
 * sure the type pointer in the swig_cast_info struct is correct.
 *
 * First off, we lookup the cast->type name to see if it is already loaded.
 * There are three cases to handle:
 *  1) If the cast->type has already been loaded AND the type we are adding
 *     casting info to has not been loaded (it is in this module), THEN we
 *     replace the cast->type pointer with the type pointer that has already
 *     been loaded.
 *  2) If BOTH types (the one we are adding casting info to, and the
 *     cast->type) are loaded, THEN the cast info has already been loaded by
 *     the previous module so we just ignore it.
 *  3) Finally, if cast->type has not already been loaded, then we add that
 *     swig_cast_info to the linked list (because the cast->type) pointer will
 *     be correct.
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#if 0
} /* c-mode */
#endif
#endif

#if 0
#define SWIGRUNTIME_DEBUG
#endif


SWIGRUNTIME void
SWIG_InitializeModule(void *clientdata) {
  size_t i;
  swig_module_info *module_head, *iter;
  int init;

  /* check to see if the circular list has been setup, if not, set it up */
  if (swig_module.next==0) {
    /* Initialize the swig_module */
    swig_module.type_initial = swig_type_initial;
    swig_module.cast_initial = swig_cast_initial;
    swig_module.next = &swig_module;
    init = 1;
  } else {
    init = 0;
  }

  /* Try and load any already created modules */
  module_head = SWIG_GetModule(clientdata);
  if (!module_head) {
    /* This is the first module loaded for this interpreter */
    /* so set the swig module into the interpreter */
    SWIG_SetModule(clientdata, &swig_module);
  } else {
    /* the interpreter has loaded a SWIG module, but has it loaded this one? */
    iter=module_head;
    do {
      if (iter==&swig_module) {
        /* Our module is already in the list, so there's nothing more to do. */
        return;
      }
      iter=iter->next;
    } while (iter!= module_head);

    /* otherwise we must add our module into the list */
    swig_module.next = module_head->next;
    module_head->next = &swig_module;
  }

  /* When multiple interpreters are used, a module could have already been initialized in
     a different interpreter, but not yet have a pointer in this interpreter.
     In this case, we do not want to continue adding types... everything should be
     set up already */
  if (init == 0) return;

  /* Now work on filling in swig_module.types */
#ifdef SWIGRUNTIME_DEBUG
  printf("SWIG_InitializeModule: size %d\n", swig_module.size);
#endif
  for (i = 0; i < swig_module.size; ++i) {
    swig_type_info *type = 0;
    swig_type_info *ret;
    swig_cast_info *cast;

#ifdef SWIGRUNTIME_DEBUG
    printf("SWIG_InitializeModule: type %d %s\n", i, swig_module.type_initial[i]->name);
#endif

    /* if there is another module already loaded */
    if (swig_module.next != &swig_module) {
      type = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, swig_module.type_initial[i]->name);
    }
    if (type) {
      /* Overwrite clientdata field */
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: found type %s\n", type->name);
#endif
      if (swig_module.type_initial[i]->clientdata) {
	type->clientdata = swig_module.type_initial[i]->clientdata;
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: found and overwrite type %s \n", type->name);
#endif
      }
    } else {
      type = swig_module.type_initial[i];
    }

    /* Insert casting types */
    cast = swig_module.cast_initial[i];
    while (cast->type) {

      /* Don't need to add information already in the list */
      ret = 0;
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: look cast %s\n", cast->type->name);
#endif
      if (swig_module.next != &swig_module) {
        ret = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, cast->type->name);
#ifdef SWIGRUNTIME_DEBUG
	if (ret) printf("SWIG_InitializeModule: found cast %s\n", ret->name);
#endif
      }
      if (ret) {
	if (type == swig_module.type_initial[i]) {
#ifdef SWIGRUNTIME_DEBUG
	  printf("SWIG_InitializeModule: skip old type %s\n", ret->name);
#endif
	  cast->type = ret;
	  ret = 0;
	} else {
	  /* Check for casting already in the list */
	  swig_cast_info *ocast = SWIG_TypeCheck(ret->name, type);
#ifdef SWIGRUNTIME_DEBUG
	  if (ocast) printf("SWIG_InitializeModule: skip old cast %s\n", ret->name);
#endif
	  if (!ocast) ret = 0;
	}
      }

      if (!ret) {
#ifdef SWIGRUNTIME_DEBUG
	printf("SWIG_InitializeModule: adding cast %s\n", cast->type->name);
#endif
        if (type->cast) {
          type->cast->prev = cast;
          cast->next = type->cast;
        }
        type->cast = cast;
      }
      cast++;
    }
    /* Set entry in modules->types array equal to the type */
    swig_module.types[i] = type;
  }
  swig_module.types[i] = 0;

#ifdef SWIGRUNTIME_DEBUG
  printf("**** SWIG_InitializeModule: Cast List ******\n");
  for (i = 0; i < swig_module.size; ++i) {
    int j = 0;
    swig_cast_info *cast = swig_module.cast_initial[i];
    printf("SWIG_InitializeModule: type %d %s\n", i, swig_module.type_initial[i]->name);
    while (cast->type) {
      printf("SWIG_InitializeModule: cast type %s\n", cast->type->name);
      cast++;
      ++j;
    }
  printf("---- Total casts: %d\n",j);
  }
  printf("**** SWIG_InitializeModule: Cast List ******\n");
#endif
}

/* This function will propagate the clientdata field of type to
* any new swig_type_info structures that have been added into the list
* of equivalent types.  It is like calling
* SWIG_TypeClientData(type, clientdata) a second time.
*/
SWIGRUNTIME void
SWIG_PropagateClientData(void) {
  size_t i;
  swig_cast_info *equiv;
  static int init_run = 0;

  if (init_run) return;
  init_run = 1;

  for (i = 0; i < swig_module.size; i++) {
    if (swig_module.types[i]->clientdata) {
      equiv = swig_module.types[i]->cast;
      while (equiv) {
        if (!equiv->converter) {
          if (equiv->type && !equiv->type->clientdata)
            SWIG_TypeClientData(equiv->type, swig_module.types[i]->clientdata);
        }
        equiv = equiv->next;
      }
    }
  }
}

#ifdef __cplusplus
#if 0
{ /* c-mode */
#endif
}
#endif


  SWIG_php_minit {
    SWIG_InitializeModule(0);



	REGISTER_INI_ENTRIES();
	char *filePath = INI_STR("FiftyOneDegreesTrieV3.data_file");
	char *propertyList = INI_STR("FiftyOneDegreesTrieV3.property_list");

	provider = new Provider(filePath, propertyList);

/* oinit subsection */
ZEND_INIT_MODULE_GLOBALS(FiftyOneDegreesTrieV3, FiftyOneDegreesTrieV3_init_globals, FiftyOneDegreesTrieV3_destroy_globals);

/* Register resource destructors for pointer types */
le_swig__p_key_type=zend_register_list_destructors_ex(_wrap_destroy_p_key_type,NULL,(char *)(SWIGTYPE_p_key_type->name),module_number);
SWIG_TypeClientData(SWIGTYPE_p_key_type,&le_swig__p_key_type);
le_swig__p_mapped_type=zend_register_list_destructors_ex(_wrap_destroy_p_mapped_type,NULL,(char *)(SWIGTYPE_p_mapped_type->name),module_number);
SWIG_TypeClientData(SWIGTYPE_p_mapped_type,&le_swig__p_mapped_type);
le_swig__p_difference_type=zend_register_list_destructors_ex(_wrap_destroy_p_difference_type,NULL,(char *)(SWIGTYPE_p_difference_type->name),module_number);
SWIG_TypeClientData(SWIGTYPE_p_difference_type,&le_swig__p_difference_type);
le_swig__p_std__mapT_std__string_std__string_t=zend_register_list_destructors_ex(_wrap_destroy_p_std__mapT_std__string_std__string_t,NULL,(char *)(SWIGTYPE_p_std__mapT_std__string_std__string_t->name),module_number);
SWIG_TypeClientData(SWIGTYPE_p_std__mapT_std__string_std__string_t,&le_swig__p_std__mapT_std__string_std__string_t);
le_swig__p_value_type=zend_register_list_destructors_ex(_wrap_destroy_p_value_type,NULL,(char *)(SWIGTYPE_p_value_type->name),module_number);
SWIG_TypeClientData(SWIGTYPE_p_value_type,&le_swig__p_value_type);
le_swig__p_std__vectorT_std__string_t=zend_register_list_destructors_ex(_wrap_destroy_p_std__vectorT_std__string_t,NULL,(char *)(SWIGTYPE_p_std__vectorT_std__string_t->name),module_number);
SWIG_TypeClientData(SWIGTYPE_p_std__vectorT_std__string_t,&le_swig__p_std__vectorT_std__string_t);
le_swig__p_Match=zend_register_list_destructors_ex(_wrap_destroy_p_Match,NULL,(char *)(SWIGTYPE_p_Match->name),module_number);
SWIG_TypeClientData(SWIGTYPE_p_Match,&le_swig__p_Match);
le_swig__p_size_type=zend_register_list_destructors_ex(_wrap_destroy_p_size_type,NULL,(char *)(SWIGTYPE_p_size_type->name),module_number);
SWIG_TypeClientData(SWIGTYPE_p_size_type,&le_swig__p_size_type);
le_swig__p_Provider=zend_register_list_destructors_ex(_wrap_destroy_p_Provider,NULL,(char *)(SWIGTYPE_p_Provider->name),module_number);
SWIG_TypeClientData(SWIGTYPE_p_Provider,&le_swig__p_Provider);
le_swig__p_std__string=zend_register_list_destructors_ex(_wrap_destroy_p_std__string,NULL,(char *)(SWIGTYPE_p_std__string->name),module_number);
SWIG_TypeClientData(SWIGTYPE_p_std__string,&le_swig__p_std__string);
CG(active_class_entry) = NULL;
/* end oinit subsection */

/* cinit subsection */
/* end cinit subsection */

    return SUCCESS;
}

PHP_RINIT_FUNCTION(FiftyOneDegreesTrieV3)
{
/* rinit section */

/* vinit subsection */
{
  zval *z_var;
  MAKE_STD_ZVAL(z_var);
  SWIG_SetPointerZval(z_var, (void*)provider, SWIGTYPE_p_Provider, 0);
  zend_hash_add(&EG(symbol_table), (char*)"provider", sizeof("provider"), (void *)&z_var,
  sizeof(zval *), NULL);
}
/* end vinit subsection */

    return SUCCESS;
}

PHP_MSHUTDOWN_FUNCTION(FiftyOneDegreesTrieV3)
{
/* shutdown section */


	delete provider;

#ifdef ZTS
    ts_free_id(FiftyOneDegreesTrieV3_globals_id);
#endif
    return SUCCESS;
}

PHP_RSHUTDOWN_FUNCTION(FiftyOneDegreesTrieV3)
{
/* rshutdown section */

    return SUCCESS;
}

PHP_MINFO_FUNCTION(FiftyOneDegreesTrieV3)
{
}
/* end init section */
